% Auto-generated chapter 33 for ibnmajah
% Hadiths in this chapter: 170

\hadithdefcmd{ibnmajah}{3657}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ مَنْصُورٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَلِيٍّ، عَنِ ابْنِ سَلاَمَةَ السُّلَمِيِّ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ أُوصِي امْرَأً بِأُمِّهِ أُوصِي امْرَأً بِأُمِّهِ أُوصِي امْرَأً بِأُمِّهِ - ثَلاَثًا - أُوصِي امْرَأً بِأَبِيهِ أُوصِي امْرَءًا بِمَوْلاَهُ الَّذِي يَلِيهِ وَإِنْ كَانَ عَلَيْهِ مِنْهُ أَذًى يُؤْذِيهِ ‏"‏ ‏.‏\hadithno{3657}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Salamah As-Sulami narrated that the Prophet (ﷺ) said:"I enjoin each one to honor his mother,I enjoin each one to honor his mother,I enjoin each one to honor his mother(three times), I enjoin each one to honor his guardian who is taking care of him, even if he is causing him some annoyance}}
\hadithdefcmd{ibnmajah}{3658}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ مَيْمُونٍ الْمَكِّيُّ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالُوا يَا رَسُولَ اللَّهِ مَنْ أَبَرُّ قَالَ ‏"‏ أُمَّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ أُمَّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ أَبَاكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ الأَدْنَى فَالأَدْنَى ‏"‏ ‏.‏\hadithno{3658}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah, may Allah be pleased with them, said that:Allah's Messenger said: "They said: 'O Messenger of Allah, whom should I treat kindly?' He said: 'Your mother.' He said: 'Then who?' He said :'Your mother." He said: 'Then who?' He said: 'Your father'. He said : 'Then who?' He said: 'The next closest and the next closest}}
\hadithdefcmd{ibnmajah}{3659}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَجْزِي وَلَدٌ وَالِدَهُ إِلاَّ أَنْ يَجِدَهُ مَمْلُوكًا فَيَشْتَرِيَهُ فَيُعْتِقَهُ ‏"‏ ‏.‏\hadithno{3659}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah, may Allah be pleased with them, narrated that:Allah's Messenger said: "No child can compensate his father unless he finds a slave, and buys him and sets him free}}
\hadithdefcmd{ibnmajah}{3660}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ الْقِنْطَارُ اثْنَا عَشَرَ أَلْفَ أُوقِيَّةٍ كُلُّ أُوقِيَّةٍ خَيْرٌ مِمَّا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ الرَّجُلَ لَتُرْفَعُ دَرَجَتُهُ فِي الْجَنَّةِ فَيَقُولُ أَنَّى هَذَا فَيُقَالُ بِاسْتِغْفَارِ وَلَدِكَ لَكَ ‏"‏ ‏.‏\hadithno{3660}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah, may Allah be pleased with them, narrated that:Allah's Messenger said: "Qintar is twelve thousand 'Uqiyah, each 'Uqiyah of which is better than what is between heaven and earth." And the Messenger of Allah(ﷺ) said: "A man will be raised in status in Paradise and will say: 'Where did this come from?' And it will be said:'From your son's praying for forgiveness for you}}
\hadithdefcmd{ibnmajah}{3661}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ يُوصِيكُمْ بِأُمَّهَاتِكُمْ - ثَلاَثًا - إِنَّ اللَّهَ يُوصِيكُمْ بِآبَائِكُمْ إِنَّ اللَّهَ يُوصِيكُمْ بِالأَقْرَبِ فَالأَقْرَبِ ‏"‏ ‏.‏\hadithno{3661}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Miqdam bin Ma'dikarib, may Allah be pleased with them, narrated that:Allah's Messenger said: "Allah enjoins you to treat your mother's kindly"-three times- "Allah enjoins you to treat your fathers kindly, Allah enjoins you to treat the closest and the next closest kindly}}
\hadithdefcmd{ibnmajah}{3662}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا عُثْمَانُ بْنُ أَبِي الْعَاتِكَةِ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ مَا حَقُّ الْوَالِدَيْنِ عَلَى وَلَدِهِمَا قَالَ ‏ "‏ هُمَا جَنَّتُكَ وَنَارُكَ ‏"‏ ‏.‏\hadithno{3662}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah narrated that a man said that:"O Allah's Messenger(ﷺ), what are the rights of parents over their child?" He said:"They are your Paradise and your Hell." (Daif)}}
\hadithdefcmd{ibnmajah}{3663}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَطَاءٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الدَّرْدَاءِ، سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْوَالِدُ أَوْسَطُ أَبْوَابِ الْجَنَّةِ فَأَضِعْ ذَلِكَ الْبَابَ أَوِ احْفَظْهُ ‏"‏ ‏.‏\hadithno{3663}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Darda' heard the Prophet (ﷺ) say that:"The father is the middle door of Paradise (i.e. the best way to Paradise), so it is up to you whether you take advantage of it or not}}
\hadithdefcmd{ibnmajah}{3664}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سُلَيْمَانَ، عَنْ أَسِيدِ بْنِ عَلِيِّ بْنِ عُبَيْدٍ، مَوْلَى بَنِي سَاعِدَةَ عَنْ أَبِيهِ، عَنْ أَبِي أُسَيْدٍ، مَالِكِ بْنِ رَبِيعَةَ قَالَ بَيْنَمَا نَحْنُ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ إِذْ جَاءَهُ رَجُلٌ مِنْ بَنِي سُلَيْمٍ فَقَالَ يَا رَسُولَ اللَّهِ أَبَقِيَ مِنْ بِرِّ أَبَوَىَّ شَىْءٌ أَبَرُّهُمَا بِهِ مِنْ بَعْدِ مَوْتِهِمَا قَالَ ‏ "‏ نَعَمْ الصَّلاَةُ عَلَيْهِمَا وَالاِسْتِغْفَارُ لَهُمَا وَإِيفَاءٌ بِعُهُودِهِمَا مِنْ بَعْدِ مَوْتِهِمَا وَإِكْرَامُ صَدِيقِهِمَا وَصِلَةُ الرَّحِمِ الَّتِي لاَ تُوصَلُ إِلاَّ بِهِمَا ‏"‏ ‏.‏\hadithno{3664}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Usaid, Malik bin Rabi'ah, said:"While we were with the Prophet(ﷺ), a man from the Banu Salamah came to him and said: " O messenger of Allah, is there anyway of honoring my parents that I can still do for them after they die?' He said: "Yes offering the funeral prayer for them, praying for forgiveness for them, fulfilling their promises after their death, honoring their freinds and upholding the ties of kinship which you would not have were it nor for them}}
\hadithdefcmd{ibnmajah}{3665}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمَ نَاسٌ مِنَ الأَعْرَابِ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالُوا أَتُقَبِّلُونَ صِبْيَانَكُمْ قَالُوا نَعَمْ ‏.‏ فَقَالُوا لَكِنَّا وَاللَّهِ مَا نُقَبِّلُ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ وَأَمْلِكُ أَنْ كَانَ اللَّهُ قَدْ نَزَعَ مِنْكُمُ الرَّحْمَةَ ‏"‏ ‏.‏\hadithno{3665}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aisha, said:"Some Bedouin people came to the Prophet(ﷺ) and said: 'Do you kiss your children?' He said: 'Yes'. He said: 'But we, by Allah, never kiss (our children)'. The Prophet(ﷺ) said: 'What can I do if Allah has taken away mercy from you?}}
\hadithdefcmd{ibnmajah}{3666}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ أَبِي رَاشِدٍ، عَنْ يَعْلَى الْعَامِرِيِّ، أَنَّهُ قَالَ جَاءَ الْحَسَنُ وَالْحُسَيْنُ يَسْعَيَانِ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَضَمَّهُمَا إِلَيْهِ وَقَالَ ‏ "‏ إِنَّ الْوَلَدَ مَبْخَلَةٌ مَجْبَنَةٌ ‏"‏ ‏.‏\hadithno{3666}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ya'la Al -Amir that he said:"Hasan and Hussain came running to the Prophet (ﷺ) and he embraced them and said: 'Children make a man a miser and a coward}}
\hadithdefcmd{ibnmajah}{3667}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مُوسَى بْنِ عُلَىٍّ، سَمِعْتُ أَبِي يَذْكُرُ، عَنْ سُرَاقَةَ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَلاَ أَدُلُّكُمْ عَلَى أَفْضَلِ الصَّدَقَةِ ابْنَتُكَ مَرْدُودَةً إِلَيْكَ لَيْسَ لَهَا كَاسِبٌ غَيْرُكَ ‏"‏ ‏.‏\hadithno{3667}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Suraqah bin Malik that the Prophet(ﷺ) said:"Shall I not tell you of the best charity? A daughter who comes back to you and has no other breadwinner apart from you." (Daif)}}
\hadithdefcmd{ibnmajah}{3668}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مِسْعَرٍ، أَخْبَرَنِي سَعْدُ بْنُ إِبْرَاهِيمَ، عَنِ الْحَسَنِ، عَنْ صَعْصَعَةَ، عَمِّ الأَحْنَفِ قَالَ دَخَلَتْ عَلَى عَائِشَةَ امْرَأَةٌ مَعَهَا ابْنَتَانِ لَهَا فَأَعْطَتْهَا ثَلاَثَ تَمَرَاتٍ فَأَعْطَتْ كُلَّ وَاحِدَةٍ مِنْهُمَا تَمْرَةً ثُمَّ صَدَعَتِ الْبَاقِيَةَ بَيْنَهُمَا ‏.‏ قَالَتْ فَأَتَى النَّبِيُّ ـ صلى الله عليه وسلم ـ فَحَدَّثْتُهُ فَقَالَ ‏ "‏ مَا عَجَبُكِ لَقَدْ دَخَلَتْ بِهِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3668}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'sa'ah the paternal uncle of Ahnaf, said:"A woman entered upon Aisha with her two daughters, and she gave her three dates. (The woman) gave each of her daughters a date, then she split the last one between them. She (Aisha) said: 'Then the Prophet(ﷺ) came and I told him about that.' He said:' Why are you surprised? She will enter Paradise because of that}}
\hadithdefcmd{ibnmajah}{3669}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ حَرْمَلَةَ بْنِ عِمْرَانَ، قَالَ سَمِعْتُ أَبَا عُشَّانَةَ الْمَعَافِرِيَّ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ كَانَ لَهُ ثَلاَثُ بَنَاتٍ فَصَبَرَ عَلَيْهِنَّ وَأَطْعَمَهُنَّ وَسَقَاهُنَّ وَكَسَاهُنَّ مِنْ جِدَتِهِ - كُنَّ لَهُ حِجَابًا مِنَ النَّارِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3669}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Uqbah bin Amir said, I heard the Messenger of Allah(ﷺ) say:"Whoever has three daughters and is patient towards them, and feeds them, gives them to drink, and clothes them from his wealth; they will be a shield for him from the Fire on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{3670}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ فِطْرٍ، عَنْ أَبِي سَعْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ رَجُلٍ تُدْرِكُ لَهُ ابْنَتَانِ فَيُحْسِنُ إِلَيْهِمَا مَا صَحِبَتَاهُ أَوْ صَحِبَهُمَا إِلاَّ أَدْخَلَتَاهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3670}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abbas that the Messenger of Allah(ﷺ) said:"There is no man whose two daughters reach the age of puberty and he treats them kindly for the time they are together, but they will gain him admittance to Paradise}}
\hadithdefcmd{ibnmajah}{3671}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا سَعِيدُ بْنُ عُمَارَةَ، أَخْبَرَنِي الْحَارِثُ بْنُ النُّعْمَانِ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ أَكْرِمُوا أَوْلاَدَكُمْ وَأَحْسِنُوا أَدَبَهُمْ ‏"‏ ‏.‏\hadithno{3671}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah(ﷺ) said:"Be kind to your children, and perfect their manners}}
\hadithdefcmd{ibnmajah}{3672}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، سَمِعَ نَافِعَ بْنَ جُبَيْرٍ، يُخْبِرُ عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُحْسِنْ إِلَى جَارِهِ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَسْكُتْ ‏"‏ ‏.‏\hadithno{3672}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Shuraih Al-Khuzai that the Prophet(ﷺ) said:"Whoever believes in the Last Day, let him treat his neighbour well. Whoever believes in Allah and Last Day, let him honor his guest. Whoever believes in Allah and the Last Day, let him say something good or else remain silent}}
\hadithdefcmd{ibnmajah}{3673}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، وَعَبْدَةُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ سَيُوَرِّثُهُ ‏"‏ ‏.‏\hadithno{3673}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aisha narrated that the Messenger of Allah(ﷺ) said:"Jibra'il kept enjoining good treatment of neighbours untol I thought that he would make neigbours heirs}}
\hadithdefcmd{ibnmajah}{3674}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا زَالَ جِبْرَائِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ سَيُوَرِّثُهُ ‏"‏ ‏.‏\hadithno{3674}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurayrah that the Messenger of Allah(ﷺ) said:"Jibra'il kept enjoining good treatment of neighbours until I thought he would make neighbours heirs}}
\hadithdefcmd{ibnmajah}{3675}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ وَجَائِزَتُهُ يَوْمٌ وَلَيْلَةٌ وَلاَ يَحِلُّ لَهُ أَنْ يَثْوِيَ عِنْدَ صَاحِبِهِ حَتَّى يُحْرِجَهُ الضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ وَمَا أَنْفَقَ عَلَيْهِ بَعْدَ ثَلاَثَةِ أَيَّامٍ فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{3675}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Shuraih Al-Khuza'i that the Messenger of Allah(ﷺ) said:"Whoever believes in the Last Day, let him honor his guest, and grant him reward for a day and a night. And it is not permissible for him to stay so long that he causes annoyance to his host. Hospitality is for three days, and whatever he spends on him after three days is charity}}
\hadithdefcmd{ibnmajah}{3676}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ قَالَ قُلْنَا لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِنَّكَ تَبْعَثُنَا فَنَنْزِلُ بِقَوْمٍ فَلاَ يَقْرُونَا فَمَا تَرَى فِي ذَلِكَ ‏.‏ قَالَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنْ نَزَلْتُمْ بِقَوْمٍ فَأَمَرُوا لَكُمْ بِمَا يَنْبَغِي لِلضَّيْفِ فَاقْبَلُوا وَإِنْ لَمْ يَفْعَلُوا فَخُذُوا مِنْهُمْ حَقَّ الضَّيْفِ الَّذِي يَنْبَغِي لَهُمْ ‏"‏ ‏.‏\hadithno{3676}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Uqbah bin Amir said:"We said to the Messenger of Allah(ﷺ): ' You send us and we stay with people who do not show us any hospitality. WHat do you think of that?' The MEssenger of Allah (ﷺ) said: 'If you stay with people and they give you what a guest deserves, then accept it. If they do not do that , then take from them what they should have offered, which a guest is entitled to}}
\hadithdefcmd{ibnmajah}{3677}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ الْمِقْدَامِ أَبِي كَرِيمَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْلَةُ الضَّيْفِ وَاجِبَةٌ فَإِنْ أَصْبَحَ بِفِنَائِهِ فَهُوَ دَيْنٌ عَلَيْهِ فَإِنْ شَاءَ اقْتَضَى وَإِنْ شَاءَ تَرَكَ ‏"‏ ‏.‏\hadithno{3677}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Miqdam Abu Karimah said:"The Messenger of Allah(ﷺ) said: ' Putting up a guest for one night is obligatory. If you find a guest at your door in the morning, then this (hospitality) is (like) a debt that you (the host) owe him. If he (the guest) wants, he may request it, and if he wants, he may leave it}}
\hadithdefcmd{ibnmajah}{3678}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ إِنِّي أُحَرِّجُ حَقَّ الضَّعِيفَيْنِ الْيَتِيمِ وَالْمَرْأَةِ ‏"‏ ‏.‏\hadithno{3678}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"O Allah, bear witness that I have issued a warning concerning (failure to fulfill) the rights of the two weak ones: Orphans and women}}
\hadithdefcmd{ibnmajah}{3679}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنْ يَحْيَى بْنِ أَبِي سُلَيْمَانَ، عَنْ زَيْدِ بْنِ أَبِي عَتَّابٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خَيْرُ بَيْتٍ فِي الْمُسْلِمِينَ بَيْتٌ فِيهِ يَتِيمٌ يُحْسَنُ إِلَيْهِ وَشَرُّ بَيْتٍ فِي الْمُسْلِمِينَ بَيْتٌ فِيهِ يَتِيمٌ يُسَاءُ إِلَيْهِ ‏"‏ ‏.‏\hadithno{3679}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"The best house among the Muslims is a house in which there is an orphan who is treated well. And the worst house among the Muslims is a house in which there is an orphan who is treated badly}}
\hadithdefcmd{ibnmajah}{3680}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ عَبْدِ الرَّحْمَنِ الْكَلْبِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الأَنْصَارِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ عَالَ ثَلاَثَةً مِنَ الأَيْتَامِ كَانَ كَمَنْ قَامَ لَيْلَهُ وَصَامَ نَهَارَهُ وَغَدَا وَرَاحَ شَاهِرًا سَيْفَهُ فِي سَبِيلِ اللَّهِ وَكُنْتُ أَنَا وَهُوَ فِي الْجَنَّةِ أَخَوَيْنِ كَهَاتَيْنِ أُخْتَانِ ‏"‏ ‏.‏ وَأَلْصَقَ إِصْبَعَيْهِ السَّبَّابَةَ وَالْوُسْطَى ‏.‏\hadithno{3680}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from `Abdullah bin `Abbas that the Messenger of Allah(ﷺ) said:"Whoever raises three orphans, is like the one who spends his nights in prayer and fasts during the day, and goes out morning and evening drawing his sword in the cause of Allah. In Paradise, he and I will be brothers like these two sisters,'and he held up his forefinger and middle finger together}}
\hadithdefcmd{ibnmajah}{3681}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ أَبَانَ بْنِ صَمْعَةَ، عَنْ أَبِي الْوَازِعِ الرَّاسِبِيِّ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ دُلَّنِي عَلَى عَمَلٍ أَنْتَفِعُ بِهِ ‏.‏ قَالَ ‏ "‏ اعْزِلِ الأَذَى عَنْ طَرِيقِ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{3681}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Barzah Al-Aslami said:"O Messenger of Allah! Tell me of an action by which I may benefit.' He said: 'Remove harmful things from the path of the Muslims}}
\hadithdefcmd{ibnmajah}{3682}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كَانَ عَلَى الطَّرِيقِ غُصْنُ شَجَرَةٍ يُؤْذِي النَّاسَ فَأَمَاطَهَا رَجُلٌ فَأُدْخِلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3682}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurayrah that the Prophet(ﷺ) said:"There was a branch of a tree that annoyed the people. A man removed it, so he was admitted to Paradise}}
\hadithdefcmd{ibnmajah}{3683}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ وَاصِلٍ، مَوْلَى أَبِي عُيَيْنَةَ عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ عُرِضَتْ عَلَىَّ أُمَّتِي بِأَعْمَالِهَا حَسَنِهَا وَسَيِّئِهَا فَرَأَيْتُ فِي مَحَاسِنِ أَعْمَالِهَا الأَذَى يُنَحَّى عَنِ الطَّرِيقِ وَرَأَيْتُ فِي سَيِّئِ أَعْمَالِهَا النُّخَاعَةَ فِي الْمَسْجِدِ لاَ تُدْفَنُ ‏"‏ ‏.‏\hadithno{3683}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Dharr that the Prophet(ﷺ) said:"My nation was shown to me with their good deeds and bad deeds. Among their good deeds I saw a harmful thing being removed from the road. And among their bad deeds I saw sputum in the mosque that had not been removed}}
\hadithdefcmd{ibnmajah}{3684}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، صَاحِبِ الدَّسْتَوَائِيِّ عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ عُبَادَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ سَقْىُ الْمَاءِ ‏"‏ ‏.‏\hadithno{3684}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sad bin Ubadah said:"I said: 'O Messenger of Allah, what charity is best?' He said: 'Giving water to drink}}
\hadithdefcmd{ibnmajah}{3685}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَصُفُّ النَّاسُ يَوْمَ الْقِيَامَةِ صُفُوفًا - وَقَالَ ابْنُ نُمَيْرٍ أَهْلُ الْجَنَّةِ - فَيَمُرُّ الرَّجُلُ مِنْ أَهْلِ النَّارِ عَلَى الرَّجُلِ فَيَقُولُ يَا فُلاَنُ أَمَا تَذْكُرُ يَوْمَ اسْتَسْقَيْتَ فَسَقَيْتُكَ شَرْبَةً قَالَ فَيَشْفَعُ لَهُ وَيَمُرُّ الرَّجُلُ فَيَقُولُ أَمَا تَذْكُرُ يَوْمَ نَاوَلْتُكَ طَهُورًا فَيَشْفَعُ لَهُ ‏"‏ ‏.‏ قَالَ ابْنُ نُمَيْرٍ ‏"‏ وَيَقُولُ يَا فُلاَنُ أَمَا تَذْكُرُ يَوْمَ بَعَثْتَنِي فِي حَاجَةِ كَذَا وَكَذَا فَذَهَبْتُ لَكَ فَيَشْفَعُ لَهُ ‏"‏ ‏.‏\hadithno{3685}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah(ﷺ) said:"On the Day of Resurrection, people will be lined up in rows, (one of the narrators) Ibn NUmair said: i.e., the people of Paradise, and a man from among the people of Hell will pass by a man (from the people of Paradise) and say: 'O so and so! Do you not remember the day when you asked for water and I gave you water to drink?" So he will intercede for him. And another man will come and say: " Do you not remember the day when I gave you water with which to purify yourself?" and he will intercede for him." (In his narration, one of the narrators) Ibn NUmair said: "And he will remember the day when you sent me to do such and such for you, and I went and did it for you?' and he will intercede for him}}
\hadithdefcmd{ibnmajah}{3686}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُعْشُمٍ، عَنْ أَبِيهِ، عَنْ عَمِّهِ، سُرَاقَةَ بْنِ جُعْشُمٍ قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ضَالَّةِ الإِبِلِ تَغْشَى حِيَاضِي قَدْ لُطْتُهَا لإِبِلِي فَهَلْ لِي مِنْ أَجْرٍ إِنْ سَقَيْتُهَا فَقَالَ ‏ "‏ نَعَمْ فِي كُلِّ ذَاتِ كَبِدٍ حَرَّى أَجْرٌ ‏"‏ ‏.‏\hadithno{3686}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suraqah bin Ju'shum said:"I asked the Messenger of Allah(ﷺ) about a lost camel that comes to my cisterns that I have prepared for my own camels - will I be rewarded if I give it some water to drink? He said: Yes, in every living being there is reward}}
\hadithdefcmd{ibnmajah}{3687}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ الْعَبْسِيِّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ يُحْرَمِ الرِّفْقَ يُحْرَمِ الْخَيْرَ ‏"‏ ‏.‏\hadithno{3687}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jarir bin Abdullah Al-Bajali that the Messenger of Allah(ﷺ) said:"Whoever is deprived of gentleness, he is deprived of goodness}}
\hadithdefcmd{ibnmajah}{3688}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ حَفْصٍ الأُبُلِّيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ رَفِيقٌ يُحِبُّ الرِّفْقَ وَيُعْطِي عَلَيْهِ مَا لاَ يُعْطِي عَلَى الْعُنْفِ ‏"‏ ‏.‏\hadithno{3688}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"Allah is Gentle and loves gentleness, and He grants reward for it that He does not grant for harshness}}
\hadithdefcmd{ibnmajah}{3689}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، عَنِ الأَوْزَاعِيِّ، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ رَفِيقٌ يُحِبُّ الرِّفْقَ فِي الأَمْرِ كُلِّهِ ‏"‏ ‏.‏\hadithno{3689}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Aishah that the Prophet(ﷺ) said:"Allah is Gentle and loves gentleness in all things}}
\hadithdefcmd{ibnmajah}{3690}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِخْوَانُكُمْ جَعَلَهُمُ اللَّهُ تَحْتَ أَيْدِيكُمْ فَأَطْعِمُوهُمْ مِمَّا تَأْكُلُونَ وَأَلْبِسُوهُمْ مِمَّا تَلْبَسُونَ وَلاَ تُكَلِّفُوهُمْ مَا يَغْلِبُهُمْ فَإِنْ كَلَّفْتُمُوهُمْ فَأَعِينُوهُمْ ‏"‏ ‏.‏\hadithno{3690}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Dhar said:"The Messenger of Allah said: '(Slaves are) your brothers whom Allah has put under your control, so feed them with the same food that you eat, clothe them with the same clothes you wear, and do not burden them with so much that htey are overwhelmed; if you do burden them, then help them}}
\hadithdefcmd{ibnmajah}{3691}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، عَنْ مُغِيرَةَ بْنِ مُسْلِمٍ، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ مُرَّةَ الطَّيِّبِ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ يَدْخُلُ الْجَنَّةَ سَيِّئُ الْمَلَكَةِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَلَيْسَ أَخْبَرْتَنَا أَنَّ هَذِهِ الأُمَّةَ أَكْثَرُ الأُمَمِ مَمْلُوكِينَ وَيَتَامَى قَالَ ‏"‏ نَعَمْ فَأَكْرِمُوهُمْ كَكَرَامَةِ أَوْلاَدِكُمْ وَأَطْعِمُوهُمْ مِمَّا تَأْكُلُونَ ‏"‏ ‏.‏ قَالُوا فَمَا يَنْفَعُنَا فِي الدُّنْيَا قَالَ ‏"‏ فَرَسٌ تَرْتَبِطُهُ تُقَاتِلُ عَلَيْهِ فِي سَبِيلِ اللَّهِ مَمْلُوكُكَ يَكْفِيكَ فَإِذَا صَلَّى فَهُوَ أَخُوكَ ‏"‏ ‏.‏\hadithno{3691}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Bakr Siddiq(RA) that the Messenger of Allah(ﷺ) said:"No person who mistreats his slave will enter Paradise." They said: " O Messenger of Allah, did you not tell us that this nation will have more slaves and orphans than any other nation?" He said: " Yes, so be as kind to them as you are to your own children, and feed them with the same food that you eat." They said: "What will benefit us in this world?" He said: "A horse that is kept ready for fighting in the cause of Allah, and your slave to take care of you, and if he performs prayer, then he is your brother(in Islam)}}
\hadithdefcmd{ibnmajah}{3692}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَابْنُ، نُمَيْرٍ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهُ ـ صلى الله عليه وسلم ـ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَدْخُلُوا الْجَنَّةَ حَتَّى تُؤْمِنُوا وَلاَ تُؤْمِنُوا حَتَّى تَحَابُّوا ‏.‏ أَوَلاَ أَدُلُّكُمْ عَلَى شَىْءٍ إِذَا فَعَلْتُمُوهُ تَحَابَبْتُمْ أَفْشُوا السَّلاَمَ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{3692}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah(RA) that the Messenger of Allah(ﷺ) said:"By the One in Whose Hand is my soul, you will not enter Paradise until you believe, and you will not believe until you love one another. Shall I not tell you of something which, if you do it, you will love one another? Spread (the greeting of) peace among yourselves}}
\hadithdefcmd{ibnmajah}{3693}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي أُمَامَةَ، قَالَ أَمَرَنَا نَبِيُّنَا ـ صلى الله عليه وسلم ـ أَنْ نُفْشِيَ السَّلاَمَ ‏.‏\hadithno{3693}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Umamah said:"Our Prophet(ﷺ) commanded us to spread (the greeting of) peace}}
\hadithdefcmd{ibnmajah}{3694}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اعْبُدُوا الرَّحْمَنَ وَأَفْشُوا السَّلاَمَ ‏"‏ ‏.‏\hadithno{3694}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abdullah bin 'Amr that the Messenger of Allah(ﷺ) said:"Worship the Most Merciful and spread (the greeting of) peace}}
\hadithdefcmd{ibnmajah}{3695}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَالِسٌ فِي نَاحِيَةِ الْمَسْجِدِ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ فَقَالَ ‏ "‏ وَعَلَيْكَ السَّلاَمُ ‏"‏ ‏.‏\hadithno{3695}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:"a man entered the masjid, and the Messenger of Allah(ﷺ) was sitting in a corner of the mosque. He prayed, then he came and greeted him with Salam(peace), and he said: 'Wa 'alaikassalm}}
\hadithdefcmd{ibnmajah}{3696}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ أَبِي سَلَمَةَ، أَنَّ عَائِشَةَ، حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لَهَا ‏ "‏ إِنَّ جِبْرَائِيلَ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏ ‏.‏ قَالَتْ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ ‏.‏\hadithno{3696}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Salamah that 'Aishah told him that the Messenger of Allah(ﷺ) said to her:"Jibrail send (greetings of) Salam to you." She said: "Wa 'alahisalam wa rahmatullah (and upon him be peace and mercy of Allah)}}
\hadithdefcmd{ibnmajah}{3697}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَمُحَمَّدُ بْنُ بِشْرٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا سَلَّمَ عَلَيْكُمْ أَحَدٌ مِنْ أَهْلِ الْكِتَابِ فَقُولُوا وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{3697}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said "the Messenger of Allah(ﷺ) said":"When any of the People of the Book greets you with Salam (peace), then say, Wa 'alaikum(and also upon you)}}
\hadithdefcmd{ibnmajah}{3698}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّهُ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ نَاسٌ مِنَ الْيَهُودِ فَقَالُوا السَّامُ عَلَيْكَ يَا أَبَا الْقَاسِمِ ‏.‏ فَقَالَ ‏ "‏ وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{3698}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aishah that some of the Jews came to the Prophet(ﷺ) and said:"Assam o alaika (death be upon you), O Abul-Qasim!" He said: "Wa 'alayikum (and also upon you)}}
\hadithdefcmd{ibnmajah}{3699}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ الْيَزَنِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي رَاكِبٌ غَدًا إِلَى الْيَهُودِ فَلاَ تَبْدَءُوهُمْ بِالسَّلاَمِ فَإِذَا سَلَّمُوا عَلَيْكُمْ فَقُولُوا وَعَلَيْكُمْ ‏"‏ ‏.‏\hadithno{3699}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu 'Abdur-Rahman Al Juhani that the Messenger of Allah(ﷺ) said:"I am riding to the Jews tomorrow. Do not initiate the greeting with them, and if they greet you, then say: Wa 'alaikum (and also upon you)}}
\hadithdefcmd{ibnmajah}{3700}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ أَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ صِبْيَانٌ فَسَلَّمَ عَلَيْنَا ‏.‏\hadithno{3700}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah(ﷺ) came to us, and we were young boys, and he greeted us with (the greeting of) peace}}
\hadithdefcmd{ibnmajah}{3701}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي حُسَيْنٍ، سَمِعَهُ مِنْ، شَهْرِ بْنِ حَوْشَبٍ يَقُولُ أَخْبَرَتْهُ أَسْمَاءُ بِنْتُ يَزِيدَ، قَالَتْ مَرَّ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي نِسْوَةٍ فَسَلَّمَ عَلَيْنَا ‏.‏\hadithno{3701}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asma bint Yazid said:"The Messenger of Allah(ﷺ) passed by us, among (a group of) women, and he greeted us with (the greeting of) peace}}
\hadithdefcmd{ibnmajah}{3702}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنْ حَنْظَلَةَ بْنِ عَبْدِ الرَّحْمَنِ السَّدُوسِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ أَيَنْحَنِي بَعْضُنَا لِبَعْضٍ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْنَا أَيُعَانِقُ بَعْضُنَا بَعْضًا قَالَ ‏"‏ لاَ وَلَكِنْ تَصَافَحُوا ‏"‏ ‏.‏\hadithno{3702}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"O Messenger of Allah! Should we bow to one another?" He said: "No." We said: "Should we embrace one another?" He said: "No, but shake hands with one another}}
\hadithdefcmd{ibnmajah}{3703}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الأَجْلَحِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ مُسْلِمَيْنِ يَلْتَقِيَانِ فَيَتَصَافَحَانِ إِلاَّ غُفِرَ لَهُمَا قَبْلَ أَنْ يَتَفَرَّقَا ‏"‏ ‏.‏\hadithno{3703}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Bara bin Azib that the Messenger of Allah(ﷺ) said:"There are no two Muslims who meet and shake hands, but they will be forgiven before they part}}
\hadithdefcmd{ibnmajah}{3704}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ ابْنِ عُمَرَ، قَالَ قَبَّلْنَا يَدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3704}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Umar said:"We kissed the hand of the Prophet(ﷺ)}}
\hadithdefcmd{ibnmajah}{3705}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَغُنْدَرٌ، وَأَبُو أُسَامَةَ عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، أَنَّ قَوْمًا، مِنَ الْيَهُودِ قَبَّلُوا يَدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَرِجْلَيْهِ ‏.‏\hadithno{3705}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Safwan bin 'Assal that:"Some people among the Jews kissed the hands and feet of the Prophet(ﷺ)}}
\hadithdefcmd{ibnmajah}{3706}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ أَبَا مُوسَى، اسْتَأْذَنَ عَلَى عُمَرَ ثَلاَثًا فَلَمْ يُؤْذَنْ لَهُ فَانْصَرَفَ فَأَرْسَلَ إِلَيْهِ عُمَرُ مَا رَدَّكَ قَالَ اسْتَأْذَنْتُ الاِسْتِئْذَانَ الَّذِي أَمَرَنَا بِهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثًا فَإِنْ أُذِنَ لَنَا دَخَلْنَا وَإِنْ لَمْ يُؤْذَنْ لَنَا رَجَعْنَا ‏.‏ قَالَ فَقَالَ لَتَأْتِيَنِّي عَلَى هَذَا بِبَيِّنَةٍ أَوْ لأَفْعَلَنَّ ‏.‏ فَأَتَى مَجْلِسَ قَوْمِهِ فَنَاشَدَهُمْ فَشَهِدُوا لَهُ فَخَلَّى سَبِيلَهُ ‏.‏\hadithno{3706}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Saeed Khudri that Abu Musa asked permission to enter upon 'Umar three times, and he did not give him permission, so he went away.'Umar sent word to him saying:"Why did you go back?" He said: "I asked permission to enter three times, as the Messenger of Allah(ﷺ) enjoined upon us, then if we are given permission we should enter, otherwise we should go back." He said: "You should bring me proof of that, or else!" Then he came to a gathering of his people and asked them to swear by Allah concerning that, and they did so, so he let him go}}
\hadithdefcmd{ibnmajah}{3707}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ وَاصِلِ بْنِ السَّائِبِ، عَنْ أَبِي سَوْرَةَ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ هَذَا السَّلاَمُ فَمَا الاِسْتِئْنَاسُ قَالَ ‏ "‏ يَتَكَلَّمُ الرَّجُلُ تَسْبِيحَةً وَتَكْبِيرَةً وَتَحْمِيدَةً وَيَتَنَحْنَحُ وَيُؤْذِنُ أَهْلَ الْبَيْتِ ‏"‏ ‏.‏\hadithno{3707}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Ayyub Ansari said:"We said: 'O Messenger of Allah(ﷺ), (we know) this (greeting of) Salam, but what does seeking permission to enter mean?' He said: 'It means a man saying SubhanAllah, and Allahu Akbar and Al Hamdulillah, and clearing his throat, announcing his arrival to the people in the house}}
\hadithdefcmd{ibnmajah}{3708}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ مُغِيرَةَ، عَنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ نُجَىٍّ، عَنْ عَلِيٍّ، قَالَ كَانَ لِي مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مُدْخَلاَنِ مُدْخَلٌ بِاللَّيْلِ وَمُدْخَلٌ بِالنَّهَارِ فَكُنْتُ إِذَا أَتَيْتُهُ وَهُوَ يُصَلِّي يَتَنَحْنَحُ لِي ‏.‏\hadithno{3708}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ali said:"I had two times of visiting the Messenger of Allah(ﷺ), at night and during the day. If I came to him when he was praying, he would clear his throat (to let me know he was praying)}}
\hadithdefcmd{ibnmajah}{3709}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ اسْتَأْذَنْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقُلْتُ أَنَا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَنَا أَنَا ‏"‏ ‏.‏\hadithno{3709}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:"I asked the Prophet(ﷺ) for permission to enter, and he said: 'Who is that?' I said: 'Me'. The Prophet(ﷺ) said " Me, me?}}
\hadithdefcmd{ibnmajah}{3710}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَابِطٍ، عَنْ جَابِرٍ، قَالَ قُلْتُ كَيْفَ أَصْبَحْتَ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ بِخَيْرٍ مِنْ رَجُلٍ لَمْ يُصْبِحْ صَائِمًا وَلَمْ يَعُدْ سَقِيمًا ‏"‏ ‏.‏\hadithno{3710}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"I said: 'How are you this morning, O Messenger of Allah?' He said: 'I am better than one who did not get up fasting, and who did not visit and sick}}
\hadithdefcmd{ibnmajah}{3711}{حَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ إِسْحَاقَ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، حَدَّثَنِي جَدِّي أَبُو أُمِّي، مَالِكُ بْنُ حَمْزَةَ بْنِ أَبِي أُسَيْدٍ السَّاعِدِيُّ عَنْ أَبِيهِ، عَنْ جَدِّهِ أَبِي أُسَيْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِلْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ وَدَخَلَ عَلَيْهِمْ فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ ‏"‏ ‏.‏ قَالُوا وَعَلَيْكَ السَّلاَمُ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ ‏.‏ قَالَ ‏"‏ كَيْفَ أَصْبَحْتُمْ ‏"‏ ‏.‏ قَالُوا بِخَيْرٍ نَحْمَدُ اللَّهَ فَكَيْفَ أَصْبَحْتَ بِأَبِينَا وَأُمِّنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَصْبَحْتُ بِخَيْرٍ أَحْمَدُ اللَّهَ ‏"‏ ‏.‏\hadithno{3711}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Usaid Sa'idi said:"The Messenger of Allah(ﷺ) said to Abbas ibn Abdul Muttalib, when he entered upon them: "Assalamu alaikum'. They said: 'Wa alaikas salamu wa ahmatullahi wa barakatuhu.' He said: 'How are you this morning?' They said: ' Well, praise is to Allah. And how are you this morning, may our fathers and mothers be ransomed for you, O Messenger of Allah?!' He said: 'I am well, praise is to Allah.'"(Daif)}}
\hadithdefcmd{ibnmajah}{3712}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سَعِيدُ بْنُ مَسْلَمَةَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَتَاكُمْ كَرِيمُ قَوْمٍ فَأَكْرِمُوهُ ‏"‏ ‏.‏\hadithno{3712}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Umar that the Messenger of Allah(ﷺ) said:"If there comes to you a man who is respected among his own people, then honor him}}
\hadithdefcmd{ibnmajah}{3713}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ عَطَسَ رَجُلاَنِ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَشَمَّتَ أَحَدَهُمَا - أَوْ سَمَّتَ - وَلَمْ يُشَمِّتِ الآخَرَ فَقِيلَ يَا رَسُولَ اللَّهِ عَطَسَ عِنْدَكَ رَجُلاَنِ فَشَمَّتَّ أَحَدَهُمَا وَلَمْ تُشَمِّتِ الآخَرَ فَقَالَ ‏ "‏ إِنَّ هَذَا حَمِدَ اللَّهَ وَإِنَّ هَذَا لَمْ يَحْمَدِ اللَّهَ ‏"‏ ‏.‏\hadithno{3713}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"Two men sneezed in he presence of the Prophet(ﷺ) and he replied (said: YarhamukAllah; may Allah have mercy on you') to one and not to the other. It was said: 'O Messenger of Allah(ﷺ), two men sneezed in your presence and you replied to one and not to the other?' He said: "'This one praised Allah(said Al-Hamdulillah fter sneezing) but that one did not}}
\hadithdefcmd{ibnmajah}{3714}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُشَمَّتُ الْعَاطِسُ ثَلاَثًا فَمَا زَادَ فَهُوَ مَزْكُومٌ ‏"‏ ‏.‏\hadithno{3714}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ilyas bin Salamah bin Akwa' that his father said:"The Messenger of Allah(ﷺ) said: 'The one who sneezes may be responded to three times; if he sneezes more than that, he has a cold}}
\hadithdefcmd{ibnmajah}{3715}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عِيسَى، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا عَطَسَ أَحَدُكُمْ فَلْيَقُلِ الْحَمْدُ لِلَّهِ ‏.‏ وَلْيَرُدَّ عَلَيْهِ مَنْ حَوْلَهُ يَرْحَمُكَ اللَّهُ ‏.‏ وَلْيَرُدَّ عَلَيْهِمْ يَهْدِيكُمُ اللَّهُ وَيُصْلِحُ بَالَكُمْ ‏"‏ ‏.‏\hadithno{3715}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ali that the Messenger of Allah(ﷺ) said:"If anyone of you sneezes, let him say: Alhamdulillah (praise be to Allah). Those around him should respond by saying: Yarhamkullah (may Allah have mercy on you). And he should respond by saying: "Yahdikum Allah wa yuslaha balakum (may Allah Guide you and set right your state)}}
\hadithdefcmd{ibnmajah}{3716}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي يَحْيَى الطَّوِيلِ، - رَجُلٌ مِنْ أَهْلِ الْكُوفَةِ - عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا لَقِيَ الرَّجُلَ فَكَلَّمَهُ لَمْ يَصْرِفْ وَجْهَهُ عَنْهُ حَتَّى يَكُونَ هُوَ الَّذِي يَنْصَرِفُ وَإِذَا صَافَحَهُ لَمْ يَنْزِعْ يَدَهُ مِنْ يَدِهِ حَتَّى يَكُونَ هُوَ الَّذِي يَنْزِعُهَا وَلَمْ يُرَ مُتَقَدِّمًا بِرُكْبَتَيْهِ جَلِيسًا لَهُ قَطُّ ‏.‏\hadithno{3716}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"Whenever the Prophet(ﷺ) met a man, he would speak to him, and would not tun away until he (the other man) was the one who turned away. And if he shook hands with him, he would not withdraw his hand until he (the other man) withdrew his hand. And he was never seen sitting with his knees ahead of the knees of the one who was sitting next to him}}
\hadithdefcmd{ibnmajah}{3717}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ عَنْ مَجْلِسِهِ ثُمَّ رَجَعَ فَهُوَ أَحَقُّ بِهِ ‏"‏ ‏.‏\hadithno{3717}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet(ﷺ) said:"When one of you gets up from his spot, then comes back, he has more right to it}}
\hadithdefcmd{ibnmajah}{3718}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ مِينَاءَ، عَنْ جَوْدَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنِ اعْتَذَرَ إِلَى أَخِيهِ بِمَعْذِرَةٍ فَلَمْ يَقْبَلْهَا كَانَ عَلَيْهِ مِثْلُ خَطِيئَةِ صَاحِبِ مَكْسٍ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الرَّحْمَنِ، - هُوَ ابْنُ مِينَاءَ - عَنْ جَوْدَانَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏\hadithno{3718}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jawdan that the Messenger of Allah(ﷺ) said:"If a man makes an excuse to his bother and he does not accept it, he will bear a burden of sin like that of the tax-collector." A hadith similar to the above has been narrated through a chain differing from the first at the 4th level of narrators}}
\hadithdefcmd{ibnmajah}{3719}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ زَمْعَةَ بْنِ صَالِحٍ، عَنِ الزُّهْرِيِّ، عَنْ وَهْبِ بْنِ عَبْدِ بْنِ زَمْعَةَ، عَنْ أُمِّ سَلَمَةَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ وَهْبِ بْنِ زَمْعَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ خَرَجَ أَبُو بَكْرٍ فِي تِجَارَةٍ إِلَى بُصْرَى قَبْلَ مَوْتِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِعَامٍ وَمَعَهُ نُعَيْمَانُ وَسُوَيْبِطُ بْنُ حَرْمَلَةَ وَكَانَا شَهِدَا بَدْرًا وَكَانَ نُعَيْمَانُ عَلَى الزَّادِ وَكَانَ سُوَيْبِطٌ رَجُلاً مَزَّاحًا فَقَالَ لِنُعَيْمَانَ أَطْعِمْنِي ‏.‏ قَالَ حَتَّى يَجِيءَ أَبُو بَكْرٍ ‏.‏ قَالَ فَلأُغِيظَنَّكَ ‏.‏ قَالَ فَمَرُّوا بِقَوْمٍ فَقَالَ لَهُمْ سُوَيْبِطٌ تَشْتَرُونَ مِنِّي عَبْدًا لِي قَالُوا نَعَمْ ‏.‏ قَالَ إِنَّهُ عَبْدٌ لَهُ كَلاَمٌ وَهُوَ قَائِلٌ لَكُمْ إِنِّي حُرٌّ ‏.‏ فَإِنْ كُنْتُمْ إِذَا قَالَ لَكُمْ هَذِهِ الْمَقَالَةَ تَرَكْتُمُوهُ فَلاَ تُفْسِدُوا عَلَىَّ عَبْدِي ‏.‏ قَالُوا لاَ بَلْ نَشْتَرِيهِ مِنْكَ ‏.‏ فَاشْتَرَوْهُ مِنْهُ بِعَشْرِ قَلاَئِصَ ثُمَّ أَتَوْهُ فَوَضَعُوا فِي عُنُقِهِ عِمَامَةً أَوْ حَبْلاً ‏.‏ فَقَالَ نُعَيْمَانُ إِنَّ هَذَا يَسْتَهْزِئُ بِكُمْ وَإِنِّي حُرٌّ لَسْتُ بِعَبْدٍ ‏.‏ فَقَالُوا قَدْ أَخْبَرَنَا خَبَرَكَ ‏.‏ فَانْطَلَقُوا بِهِ فَجَاءَ أَبُو بَكْرٍ فَأَخْبَرُوهُ بِذَلِكَ ‏.‏ قَالَ فَاتَّبَعَ الْقَوْمَ وَرَدَّ عَلَيْهِمُ الْقَلاَئِصَ وَأَخَذَ نُعَيْمَانَ ‏.‏ قَالَ فَلَمَّا قَدِمُوا عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَأَخْبَرُوهُ ‏.‏ قَالَ فَضَحِكَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَصْحَابُهُ مِنْهُ حَوْلاً ‏.‏\hadithno{3719}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Salamah said:"Abu Bakr went out to trade in Busra, one year before the Prophet (ﷺ) died, and with him were Nu`aiman and Suwaibit the sons of Harmalah, who had been present at Badr. Nu`aiman was in charge of the provisions, and Suwaibit was a man who joked a lot. He said to Nu`aiman: 'Feed me'. He said: 'Not until Abu Bakr comes'. He said: 'Then I will have to annoy you'. Then they passed by some people, and Suwaibit said to them: 'Will you buy a slave from me?' They said: 'Yes'. He said 'He is a slave who talks a lot and he will tell you, "I am a free man". If you are going to let him go when he says that to you, do not bother buying him.' They said: 'We will buy him from you.' So they bought him from him in return for ten young she-camels, then they brought him and tied a turban or a rope around his neck. Nu`aiman said: 'This man is making fun of you. I am a free man, not a slave.' They said: 'He has already told us about you; and they took him off.' Then Abu Bakr came and he (Suwaibit) told him about that. So he followed those people and returned their camels to them, and took Nu`aiman back. When they came to the Prophet (ﷺ) they told him what had happened, and the Prophet (ﷺ) and his companions laughed about it for a year}}
\hadithdefcmd{ibnmajah}{3720}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُخَالِطُنَا حَتَّى يَقُولَ لأَخٍ لِي صَغِيرٍ ‏ "‏ يَا أَبَا عُمَيْرٍ مَا فَعَلَ النُّغَيْرُ ‏"‏ ‏.‏ قَالَ وَكِيعٌ يَعْنِي طَيْرًا كَانَ يَلْعَبُ بِهِ ‏.‏\hadithno{3720}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Taiyah said:"I heard Anas Bin Malik say: The Messenger of Allah (ﷺ) used to mix with us so much that he said to a little brother of mine: "O Abu `Umair, what happened to the Nughair (one of the narrators Waki` said that it means a bird that he used to play with)}}
\hadithdefcmd{ibnmajah}{3721}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ نَتْفِ الشَّيْبِ وَقَالَ ‏ "‏ هُوَ نُورُ الْمُؤْمِنِ ‏"‏ ‏.‏\hadithno{3721}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Sh'uaib from his father, that his grandfather said:"The Messenger of Allah(ﷺ) forbade plucking out white hairs and said: 'It is the light of the believer}}
\hadithdefcmd{ibnmajah}{3722}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ أَبِي الْمُنِيبِ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُقْعَدَ بَيْنَ الظِّلِّ وَالشَّمْسِ ‏.‏\hadithno{3722}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Buraidah, from his father, that the Prophet(ﷺ) :"forbade sitting between the shade and sun}}
\hadithdefcmd{ibnmajah}{3723}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ قَيْسِ بْنِ طِخْفَةَ الْغِفَارِيِّ، عَنْ أَبِيهِ، قَالَ أَصَابَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ نَائِمًا فِي الْمَسْجِدِ عَلَى بَطْنِي فَرَكَضَنِي بِرِجْلِهِ وَقَالَ ‏ "‏ مَا لَكَ وَلِهَذَا النَّوْمِ هَذِهِ نَوْمَةٌ يَكْرَهُهَا اللَّهُ أَوْ يُبْغِضُهَا اللَّهُ ‏"‏ ‏.‏\hadithno{3723}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Qais bin Tihfah Al-Ghifari that his father said:"The Messenger of Allah(ﷺ) found me sleeping in the masjid on my stomach. He nudged me with his foot and said: 'Why are you sleeping like this? This is a kind of sleep that Allah dislikes,' or 'that Allah hates}}
\hadithdefcmd{ibnmajah}{3724}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ أَبِيهِ، عَنِ ابْنِ طِخْفَةَ الْغِفَارِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ مَرَّ بِيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَنَا مُضْطَجِعٌ عَلَى بَطْنِي فَرَكَضَنِي بِرِجْلِهِ وَقَالَ ‏ "‏ يَا جُنَيْدِبُ إِنَّمَا هَذِهِ ضِجْعَةُ أَهْلِ النَّارِ ‏"‏ ‏.‏\hadithno{3724}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Dharr said:"The Prophet(ﷺ) passed by me and I was lying on my stomach. He nudged me with his foot and said: 'O Junaidib! This is how the people of Hell lie}}
\hadithdefcmd{ibnmajah}{3725}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا سَلَمَةُ بْنُ رَجَاءٍ، عَنِ الْوَلِيدِ بْنِ جَمِيلٍ الدِّمَشْقِيِّ، أَنَّهُ سَمِعَ الْقَاسِمَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ أَبِي أُمَامَةَ، قَالَ مَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى رَجُلٍ نَائِمٍ فِي الْمَسْجِدِ مُنْبَطِحٍ عَلَى وَجْهِهِ فَضَرَبَهُ بِرِجْلِهِ وَقَالَ ‏ "‏ قُمْ وَاقْعُدْ فَإِنَّهَا نَوْمَةٌ جَهَنَّمِيَّةٌ ‏"‏ ‏.‏\hadithno{3725}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Umamah said:"The Prophet(ﷺ) passed by a man who was sleeping in the masjid, lying on his face. He struck him with his foot and said: 'Get up' or; 'Sit up, fo this is a hellish kind of sleep}}
\hadithdefcmd{ibnmajah}{3726}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنِ الْوَلِيدِ بْنِ عَبْدِ اللَّهِ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنِ اقْتَبَسَ عِلْمًا مِنَ النُّجُومِ اقْتَبَسَ شُعْبَةً مِنَ السِّحْرِ زَادَ مَا زَادَ ‏"‏ ‏.‏\hadithno{3726}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Abbas that the Messenger of Allah(ﷺ) said:"Whoever learns about the stars, he learns a branch of magic; the more he learns (of the former) the more he learns (of the latter)}}
\hadithdefcmd{ibnmajah}{3727}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا ثَابِتٌ الزُّرَقِيُّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَسُبُّوا الرِّيحَ فَإِنَّهَا مِنْ رَوْحِ اللَّهِ تَأْتِي بِالرَّحْمَةِ وَالْعَذَابِ وَلَكِنْ سَلُوا اللَّهَ مِنْ خَيْرِهَا وَتَعَوَّذُوا بِاللَّهِ مِنْ شَرِّهَا ‏"‏ ‏.‏\hadithno{3727}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"Do not curse the wind, for it is from the mercy of Allah, bringing Rahmah (i.e., rain and breezes), or destruction. But ask Allah for its goodness, and seek refuge with Allah from its evil}}
\hadithdefcmd{ibnmajah}{3728}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا الْعُمَرِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَحَبُّ الأَسْمَاءِ إِلَى اللَّهِ عَزَّ وَجَلَّ عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ ‏"‏ ‏.‏\hadithno{3728}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet(ﷺ) said:"The most beloved of names to Allah are 'Abdullah and 'Abdur-Rahman}}
\hadithdefcmd{ibnmajah}{3729}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَئِنْ عِشْتُ إِنْ شَاءَ اللَّهُ لأَنْهَيَنَّ أَنْ يُسَمَّى رَبَاحٌ وَنَجِيحٌ وَأَفْلَحُ وَنَافِعٌ وَيَسَارٌ ‏"‏ ‏.‏\hadithno{3729}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar ibn Al-Khattab that the Prophet(ﷺ) said:"If I live- if Allah wills - I will forbid the names Rabah(profit), Najih(saved), Aflah (Successful), Nafi (beneficial) and Yasar(prosperity)}}
\hadithdefcmd{ibnmajah}{3730}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنِ الرُّكَيْنِ، عَنْ أَبِيهِ، عَنْ سَمُرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نُسَمِّيَ رَقِيقَنَا أَرْبَعَةَ أَسْمَاءٍ أَفْلَحُ وَنَافِعٌ وَرَبَاحٌ وَيَسَارٌ ‏.‏\hadithno{3730}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Samurah said:"The Messenger of Allah(ﷺ) forbade giving our slaves four names: Aflah (successful), Nafi' (beneficial), Rabah (profit) and Yasar(prosperity)}}
\hadithdefcmd{ibnmajah}{3731}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا أَبُو عَقِيلٍ، حَدَّثَنَا مُجَالِدُ بْنُ سَعِيدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ لَقِيتُ عُمَرَ بْنَ الْخَطَّابِ فَقَالَ مَنْ أَنْتَ فَقُلْتُ مَسْرُوقُ بْنُ الأَجْدَعِ ‏.‏ فَقَالَ عُمَرُ سَمِعْ��ُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الأَجْدَعُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{3731}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Masruq said:"I met 'Umar bin Khattab and he said: 'Who are you?' I said: 'Masruq bin Adja'.' 'Umar said: 'I heard the Messenger of Allah(ﷺ) saying,"Ajda' is a devil}}
\hadithdefcmd{ibnmajah}{3732}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، قَالَ سَمِعْتُ أَبَا رَافِعٍ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ زَيْنَبَ، كَانَ اسْمُهَا بَرَّةَ فَقِيلَ لَهَا تُزَكِّي نَفْسَهَا فَسَمَّاهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ زَيْنَبَ ‏.‏\hadithno{3732}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:"Zainab used to be called "Barrah" (good), and it was said that she was praising herself. So the Messenger of Allah(ﷺ) changed her name to Zainab}}
\hadithdefcmd{ibnmajah}{3733}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ ابْنَةً لِعُمَرَ، كَانَ يُقَالُ لَهَا عَاصِيَةُ فَسَمَّاهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَمِيلَةَ ‏.‏\hadithno{3733}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Umar that:"a daughter of 'Umar was Asiyah(disobedient) then the Messenger of Allah(ﷺ) named her 'Jamilah' (beautiful)}}
\hadithdefcmd{ibnmajah}{3734}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى أَبُو الْمُحَيَّاةِ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، حَدَّثَنَى ابْنُ أَخِي عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ قَدِمْتُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَلَيْسَ اسْمِي عَبْدَ اللَّهِ بْنَ سَلاَمٍ فَسَمَّانِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَبْدَ اللَّهِ بْنَ سَلاَمٍ ‏.‏\hadithno{3734}\hadithgrade{Al-Albani: Munkar Daif; Muhammad Fouad Abd al-Baqi: Munkar Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abdullah bin Salam said:"I came to the Messenger of Allah(ﷺ), and my name was not Abdullah bin Salam. The Messenger of Allah(ﷺ) named me Abdullah bin Salam}}
\hadithdefcmd{ibnmajah}{3735}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكَنَّوْا بِكُنْيَتِي ‏"‏ ‏.‏\hadithno{3735}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Muhammad that they heard Abu Hurairah say:"Abul Qasim(ﷺ) said: 'Call yourselves by my name but do not call yourselves by my Kunyah}}
\hadithdefcmd{ibnmajah}{3736}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكَنَّوْا بِكُنْيَتِي ‏"‏ ‏.‏\hadithno{3736}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Messenger of Allah(ﷺ) said:"Call yourselves by my name but do not call yourselves by my Kunyah}}
\hadithdefcmd{ibnmajah}{3737}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِالْبَقِيعِ فَنَادَى رَجُلٌ رَجُلاً يَا أَبَا الْقَاسِمِ فَالْتَفَتَ إِلَيْهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ إِنِّي لَمْ أَعْنِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏ ‏.‏\hadithno{3737}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah(ﷺ) was in Baqi', and a man called out to another man: 'O Abul-Qasim!' The Messenger of Allah(ﷺ) turned to him, and he said: 'I didn't mean you.' The Messenger of Allah(ﷺ) said: 'Call yourselves by my name but do not call yourselves by my Kunyah}}
\hadithdefcmd{ibnmajah}{3738}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ حَمْزَةَ بْنِ صُهَيْبٍ، أَنَّ عُمَرَ، قَالَ لِصُهَيْبٍ مَا لَكَ تَكْتَنِي بِأَبِي يَحْيَى وَلَيْسَ لَكَ وَلَدٌ ‏.‏ قَالَ كَنَّانِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِأَبِي يَحْيَى ‏.‏\hadithno{3738}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hamzah bin Suhaib that Umar said to Suhaib:"Why are you called Abu Yahya when you do not have a son?" He said: "The Messenger of Allah(ﷺ) gave me the Kunya of Abu Yahya}}
\hadithdefcmd{ibnmajah}{3739}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ مَوْلًى، لِلزُّبَيْرِ عَنْ عَائِشَةَ، ‏.‏ أَنَّهَا قَالَتْ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ كُلُّ أَزْوَاجِكَ كَنَّيْتَهُ غَيْرِي ‏.‏ قَالَ ‏ "‏ فَأَنْتِ أُمُّ عَبْدِ اللَّهِ ‏"‏ ‏.‏\hadithno{3739}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Aisha that she said to the Prophet(ﷺ):"All of your wives have a Kunyah except me." He said: "You are Umm Abdullah}}
\hadithdefcmd{ibnmajah}{3740}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَأْتِينَا فَيَقُولُ لأَخٍ لِي وَكَانَ صَغِيرًا ‏ "‏ يَا أَبَا عُمَيْرٍ ‏"‏ ‏.‏\hadithno{3740}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Prophet(ﷺ) used to come to us and say to a brother of mine, who was small: 'O Abu Umair}}
\hadithdefcmd{ibnmajah}{3741}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي جَبِيرَةَ بْنِ الضَّحَّاكِ، قَالَ فِينَا نَزَلَتْ مَعْشَرَ الأَنْصَارِ ‏\{وَلاَ تَنَابَزُوا بِالأَلْقَابِ‏)‏ قَدِمَ عَلَيْنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ وَالرَّجُلُ مِنَّا لَهُ الاِسْمَانِ وَالثَّلاَثَةُ فَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ رُبَّمَا دَعَاهُمْ بِبَعْضِ تِلْكَ الأَسْمَاءِ فَيُقَالُ يَا رَسُولَ اللَّهِ إِنَّهُ يَغْضَبُ مِنْ هَذَا ‏.‏ فَنَزَلَتْ ‏\{وَلاَ تَنَابَزُوا بِالأَلْقَابِ\}‏ ‏.‏\hadithno{3741}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Jabirah bin Dahhak said:"(Allah's saying) "Nor insult one another by nicknames(Surah Al Hujarat 49:11)" was revealed concerning us, the Ansar. When the Prophet(ﷺ) came to us, a man among us would have two or three names, and the Prophet(ﷺ) might call him by one of those names, only to be told: "O Messenger of Allah(ﷺ), he does not like that name." Then:"Nor insult one another by nicknames." was revealed}}
\hadithdefcmd{ibnmajah}{3742}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنِ الْمِقْدَادِ بْنِ عَمْرٍو، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَحْثُوَ فِي وُجُوهِ الْمَدَّاحِينَ التُّرَابَ ‏.‏\hadithno{3742}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Miqdad bin 'Amr said:"The Messenger of Allah(ﷺ) commanded us to throw dust in the faces of those who praise others}}
\hadithdefcmd{ibnmajah}{3743}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ مَعْبَدٍ الْجُهَنِيِّ، عَنْ مُعَاوِيَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِيَّاكُمْ وَالتَّمَادُحَ فَإِنَّهُ الذَّبْحُ ‏"‏ ‏.‏\hadithno{3743}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Muawiyah said:"I heard the Messenger of Allah(ﷺ) say: 'Beware of praising one another, for it is slaughtering (one another)}}
\hadithdefcmd{ibnmajah}{3744}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ مَدَحَ رَجُلٌ رَجُلاً عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ وَيْحَكَ قَطَعْتَ عُنُقَ صَاحِبِكَ ‏"‏ ‏.‏ مِرَارًا ثُمَّ قَالَ ‏"‏ إِنْ كَانَ أَحَدُكُمْ مَادِحًا أَخَاهُ فَلْيَقُلْ أَحْسِبُهُ وَلاَ أُزَكِّي عَلَى اللَّهِ أَحَدًا ‏"‏ ‏.‏\hadithno{3744}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abdur-Rahman bin Abu Bakrah that his father said:"A man praised another man in the presence of Messenger of Allah(ﷺ). The Messenger of Allah(ﷺ) said: 'Woe to you,you have cut the neck of your companion,'several times. Then he said: 'If anyone of you praises his brother, let him say: "I think he is lie this, but I do not sanctify anyone before Allah}}
\hadithdefcmd{ibnmajah}{3745}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، عَنْ شَيْبَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُسْتَشَارُ مُؤْتَمَنٌ ‏"‏ ‏.‏\hadithno{3745}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"One who is consulted is entrusted}}
\hadithdefcmd{ibnmajah}{3746}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، عَنْ شَرِيكٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُسْتَشَارُ مُؤْتَمَنٌ ‏"‏ ‏.‏\hadithno{3746}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Mas'ud that the Messenger of Allah(ﷺ) said:"One who is consulted is entrusted}}
\hadithdefcmd{ibnmajah}{3747}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، وَعَلِيُّ بْنُ هَاشِمٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اسْتَشَارَ أَحَدُكُمْ أَخَاهُ فَلْيُشِرْ عَلَيْهِ ‏"‏ ‏\hadithno{3747}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that that the Messenger of Allah(ﷺ) said:"If one of you consults his brother, then let him advise him}}
\hadithdefcmd{ibnmajah}{3748}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى وَجَعْفَرُ بْنُ عَوْنٍ جَمِيعًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادِ بْنِ أَنْعُمٍ الإِفْرِيقِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تُفْتَحُ لَكُمْ أَرْضُ الأَعَاجِمِ وَسَتَجِدُونَ فِيهَا بُيُوتًا يُقَالُ لَهَا الْحَمَّامَاتُ فَلاَ يَدْخُلْهَا الرِّجَالُ إِلاَّ بِإِزَارٍ وَامْنَعُوا النِّسَاءَ أَنْ يَدْخُلْنَهَا إِلاَّ مَرِيضَةً أَوْ نُفَسَاءَ ‏"‏ ‏.‏\hadithno{3748}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abdullah bin Amr said:"The Messenger of Allah(ﷺ) said: 'You will conquer the lands of the non-Arabs, where you will find houses called Hammamat (bathhouses). Men Should only enter them wearing a waist wrap, and do not let women enter them unless they are sick or bleeding following childbirth}}
\hadithdefcmd{ibnmajah}{3749}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ شَدَّادٍ، عَنْ أَبِي عُذْرَةَ، - قَالَ وَكَانَ قَدْ أَدْرَكَ النَّبِيَّ ـ صلى الله عليه وسلم ـ - عَنْ عَائِشَةَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى الرِّجَالَ وَالنِّسَاءَ مِنَ الْحَمَّامَاتِ ثُمَّ رَخَّصَ لِلرِّجَالِ أَنْ يَدْخُلُوهَا فِي الْمَيَازِرِ وَلَمْ يُرَخِّصْ لِلنِّسَاءِ ‏.‏\hadithno{3749}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Aisha that the Prophet(ﷺ):forbade men and women to enter bathhouses, then he allowed men to enter them wearing a waist wrap, but he did not make the same allowance for women}}
\hadithdefcmd{ibnmajah}{3750}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي الْمَلِيحِ الْهُذَلِيِّ، أَنَّ نِسْوَةً، مِنْ أَهْلِ حِمْصَ اسْتَأْذَنَّ عَلَى عَائِشَةَ فَقَالَتْ لَعَلَّكُنَّ مِنَ اللَّوَاتِي يَدْخُلْنَ الْحَمَّامَاتِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ أَيُّمَا امْرَأَةٍ وَضَعَتْ ثِيَابَهَا فِي غَيْرِ بَيْتِ زَوْجِهَا فَقَدْ هَتَكَتْ سِتْرَ مَا بَيْنَهَا وَبَيْنَ اللَّهِ ‏"‏ ‏.‏\hadithno{3750}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Malih AL-HUdhail that some women from the people of Hims asked permission to enter upon Aisha. She said:"Perhaps you are among those (women) who enter bathhouses? I heard the Messenger of Allah(ﷺ) say: 'Any woman who takes off her clothes anywhere but in her husband's house, has torn the screen between her and Allah}}
\hadithdefcmd{ibnmajah}{3751}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي هَاشِمٍ الرُّمَّانِيِّ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا اطَّلَى بَدَأَ بِعَوْرَتِهِ فَطَلاَهَا بِالنُّورَةِ وَسَائِرَ جَسَدِهِ أَهْلُهُ ‏.‏\hadithno{3751}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that when the Prophet(ﷺ) would apply (it):he began with his private area, coating it with hair removing chemical. And his wife would do the remainder of his body}}
\hadithdefcmd{ibnmajah}{3752}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ كَامِلٍ أَبِي الْعَلاَءِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ اطَّلَى وَوَلِيَ عَانَتَهُ بِيَدِهِ ‏.‏\hadithno{3752}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that:"the Prophet(ﷺ) would coat (with hair removing chemical) and remove the pubic hairs with his hand}}
\hadithdefcmd{ibnmajah}{3753}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْهِقْلُ بْنُ زِيَادٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ الأَسْلَمِيِّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَقُصُّ عَلَى النَّاسِ إِلاَّ أَمِيرٌ أَوْ مَأْمُورٌ أَوْ مُرَاءٍ ‏"‏ ‏.‏\hadithno{3753}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Amr bin Shuaib, from his father, from his grandfather, that the Messenger of Allah(ﷺ) said:"No one tells the stories to the people (for the purpose of exhortation) except a ruler, one appointed by a ruler, or a show-off}}
\hadithdefcmd{ibnmajah}{3754}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الْعُمَرِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمْ يَكُنِ الْقَصَصُ فِي زَمَنِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَلاَ زَمَنِ أَبِي بَكْرٍ وَلاَ زَمَنِ عُمَرَ ‏.‏\hadithno{3754}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn Umar said:"Stories (for the purpose of exhortation) were unknown at the time of the Messenger of Allah(ﷺ), the time of Abu Bakr and Umar}}
\hadithdefcmd{ibnmajah}{3755}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ مِنَ الشِّعْرِ لَحِكْمَةً ‏"‏ ‏.‏\hadithno{3755}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ubbay bin Ka'b that the Messenger of Allah(ﷺ) said:"In some poetry there is wisdom}}
\hadithdefcmd{ibnmajah}{3756}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَائِدَةَ، عَنِ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ ‏ "‏ إِنَّ مِنَ الشِّعْرِ حِكَمًا ‏"‏ ‏.‏\hadithno{3756}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas that the Prophet(ﷺ) said:"In some poetry there is wisdom}}
\hadithdefcmd{ibnmajah}{3757}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَصْدَقُ كَلِمَةٍ قَالَهَا الشَّاعِرُ كَلِمَةُ لَبِيدٍ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلُ وَكَادَ أُمَيَّةُ بْنُ أَبِي الصَّلْتِ أَنْ يُسْلِمَ ‏"‏ ‏.‏\hadithno{3757}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"The truest of wods spoken by the poet are the words of Labid: Everything except Allah is false.' And Abu Umayyah bin Abu Salt nearly accepted Islam}}
\hadithdefcmd{ibnmajah}{3758}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْلَى، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، قَالَ أَنْشَدْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مِائَةَ قَافِيَةٍ مِنْ شِعْرِ أُمَيَّةَ بْنِ أَبِي الصَّلْتِ يَقُولُ بَيْنَ كُلِّ قَافِيَةٍ ‏"‏ هِيهِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ كَادَ أَنْ يُسْلِمَ ‏"‏ ‏.‏\hadithno{3758}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Amr bin Sharid that his father said:"I recited one hundered verses of the poetry of Umayyah bin Abu Salt to the Messenger of Allah(ﷺ), and after every line he said, "More". And he said: "He nearly accepted Islam}}
\hadithdefcmd{ibnmajah}{3759}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا حَفْصٌ، وَأَبُو مُعَاوِيَةَ وَوَكِيعٌ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لأَنْ يَمْتَلِئَ جَوْفُ الرَّجُلِ قَيْحًا حَتَّى يَرِيَهُ خَيْرٌ لَهُ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏ إِلاَّ أَنَّ حَفْصًا لَمْ يَقُلْ يَرِيَهُ ‏.‏\hadithno{3759}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"If a man were to fill his stomach completely with pus until it destroyed him, that would be better for him than filling (his mind) with poetry}}
\hadithdefcmd{ibnmajah}{3760}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي قَتَادَةُ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لأَنْ يَمْتَلِئَ جَوْفُ أَحَدِكُمْ قَيْحًا حَتَّى يَرِيَهُ خَيْرٌ لَهُ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏\hadithno{3760}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sad bin Abu Waqas that the Prophet(ﷺ) said:"If a man were to fill his stomach completely with pus until it destroyed him, that would be better for him than filling (his mind) with poetry}}
\hadithdefcmd{ibnmajah}{3761}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَعْظَمَ النَّاسِ فِرْيَةً لَرَجُلٌ هَاجَى رَجُلاً فَهَجَا الْقَبِيلَةَ بِأَسْرِهَا وَرَجُلٌ انْتَفَى مِنْ أَبِيهِ وَزَنَّى أُمَّهُ ‏"‏ ‏.‏\hadithno{3761}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aisha that the Messenger of Allah(ﷺ) said:"The worst of all people lying is a man who trades insults with another man, disparaging the entire tribe, and a man who denies his father and accuses his mother of adultery}}
\hadithdefcmd{ibnmajah}{3762}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَعِبَ بِالنَّرْدِ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{3762}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah(ﷺ) said: 'Whoever plays backgammon has disobeyed Allah and His Messenger}}
\hadithdefcmd{ibnmajah}{3763}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ لَعِبَ بِالنَّرْدَشِيرِ فَكَأَنَّمَا غَمَسَ يَدَهُ فِي لَحْمِ خِنْزِيرٍ وَدَمِهِ ‏"‏ ‏.‏\hadithno{3763}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Buraidah from his father that the Prophet(ﷺ) said:"Whoever plays backgammon, it is as if he dipped his hand in the flesh and blood of a pig}}
\hadithdefcmd{ibnmajah}{3764}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَظَرَ إِلَى إِنْسَانٍ يَتْبَعُ طَائِرًا فَقَالَ ‏ "‏ شَيْطَانٌ يَتْبَعُ شَيْطَانًا ‏"‏ ‏.‏\hadithno{3764}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Prophet(ﷺ) looked at a man who was chasing a bird and said:"A devil chasing a devil}}
\hadithdefcmd{ibnmajah}{3765}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ رَأَى رَجُلاً يَتْبَعُ حَمَامَةً فَقَالَ ‏ "‏ شَيْطَانٌ يَتْبَعُ شَيْطَانَةً ‏"‏ ‏.‏\hadithno{3765}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet(ﷺ) saw a man chasing a pigeon and said:"A male devil following a female devil}}
\hadithdefcmd{ibnmajah}{3766}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنِ الْحَسَنِ بْنِ أَبِي الْحَسَنِ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَأَى رَجُلاً وَرَاءَ حَمَامَةٍ فَقَالَ ‏ "‏ شَيْطَانٌ يَتْبَعُ شَيْطَانَةً ‏"‏ ‏.‏\hadithno{3766}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Uthman bin Affan that the Messenger of Allah(ﷺ) saw a man following a pigeon and said:"A male devil chasing a female devil}}
\hadithdefcmd{ibnmajah}{3767}{حَدَّثَنَا أَبُو نَصْرٍ، مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ حَدَّثَنَا رَوَّادُ بْنُ الْجَرَّاحِ، حَدَّثَنَا أَبُو سَعْدٍ السَّاعِدِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلاً يَتْبَعُ حَمَامًا فَقَالَ ‏ "‏ شَيْطَانٌ يَتْبَعُ شَيْطَانًا ‏"‏ ‏.‏\hadithno{3767}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah(ﷺ) saw a man chasing a pigeon and said: 'A devil chasing a devil}}
\hadithdefcmd{ibnmajah}{3768}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عَاصِمِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْ يَعْلَمُ أَحَدُكُمْ مَا فِي الْوَحْدَةِ مَا سَارَ أَحَدٌ بِلَيْلٍ وَحْدَهُ ‏"‏ ‏.‏\hadithno{3768}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah(ﷺ) said:"If anyone of you knew what is wrong with being alone, no one would travel at night by himself}}
\hadithdefcmd{ibnmajah}{3769}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَتْرُكُوا النَّارَ فِي بُيُوتِكُمْ حِينَ تَنَامُونَ ‏"‏ ‏.‏\hadithno{3769}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim, from his father, that the Prophet(ﷺ) said:"Do not leave fire in your houses when you go to sleep}}
\hadithdefcmd{ibnmajah}{3770}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ احْتَرَقَ بَيْتٌ بِالْمَدِينَةِ عَلَى أَهْلِهِ فَحُدِّثَ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِشَأْنِهِمْ فَقَالَ ‏ "‏ إِنَّمَا هَذِهِ النَّارُ عَدُوٌّ لَكُمْ فَإِذَا نِمْتُمْ فَأَطْفِئُوهَا عَنْكُمْ ‏"‏ ‏.‏\hadithno{3770}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"A house burned down in Al-Madinah, with its occupants inside. The Prophet(ﷺ) was told of what had happened, and he said: 'This fire is an enemy to you. When you go to sleep, extinguish it}}
\hadithdefcmd{ibnmajah}{3771}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عَبْدِ الْمَلِكِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَهَانَا فَأَمَرَنَا أَنْ نُطْفِئَ سِرَاجَنَا ‏.‏\hadithno{3771}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah(ﷺ) commanded us (to do some things) and forbade us (to do some things), and he commanded us to extinguish our lamps}}
\hadithdefcmd{ibnmajah}{3772}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هِشَامٌ، عَنِ الْحَسَنِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَنْزِلُوا عَلَى جَوَادِّ الطَّرِيقِ وَلاَ تَقْضُوا عَلَيْهَا الْحَاجَاتِ ‏"‏ ‏.‏\hadithno{3772}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Messenger of Allah(ﷺ) said:"Do not camp on the middle of the road, or relieve yourselves there}}
\hadithdefcmd{ibnmajah}{3773}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عَاصِمٍ، حَدَّثَنَا مُوَرِّقٌ الْعِجْلِيُّ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَدِمَ مِنْ سَفَرٍ تُلُقِّيَ بِنَا ‏.‏ قَالَ فَتُلُقِّيَ بِي وَبِالْحَسَنِ أَوْ بِالْحُسَيْنِ ‏.‏ قَالَ فَحَمَلَ أَحَدَنَا بَيْنَ يَدَيْهِ وَالآخَرَ خَلْفَهُ حَتَّى قَدِمْنَا الْمَدِينَةَ ‏"‏ ‏.‏\hadithno{3773}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Ja'far said:"Whenever the Messenger of Allah(ﷺ) came back from a journey, he would be met by us(children). (One day) he was met by me and Hasan or Husain. He made one of us ride in front of him and the other behind him, until we came to Al-Madinah}}
\hadithdefcmd{ibnmajah}{3774}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا بَقِيَّةُ، أَنْبَأَنَا أَبُو أَحْمَدَ الدِّمَشْقِيُّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تَرِّبُوا صُحُفَكُمْ أَنْجَحُ لَهَا إِنَّ التُّرَابَ مُبَارَكٌ ‏"‏ ‏.‏\hadithno{3774}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Messenger of Allah(ﷺ) said:"Put dust on your writings, because it is better, and dust is blessed (being humble in correspondence brings good results)}}
\hadithdefcmd{ibnmajah}{3775}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا كُنْتُمْ ثَلاَثَةً فَلاَ يَتَنَاجَى اثْنَانِ دُونَ صَاحِبِهِمَا فَإِنَّ ذَلِكَ يُحْزِنُهُ ‏"‏ ‏.‏\hadithno{3775}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abdullah that the Messenger of Allah(ﷺ) said:"When you are three, two should not converse (privately) to the exclusion of their companion, because that makes him sad}}
\hadithdefcmd{ibnmajah}{3776}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَتَنَاجَى اثْنَانِ دُونَ الثَّالِثِ ‏.‏\hadithno{3776}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah(ﷺ) forbade two to converse (privately) to the exclusion of a third}}
\hadithdefcmd{ibnmajah}{3777}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفَيْانُ بْنُ عُيَيْنَةَ، قَالَ قُلْتُ لِعَمْرِو بْنِ دِينَارٍ سَمِعْتَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَرَّ رَجُلٌ بِسِهَامٍ فِي الْمَسْجِدِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَمْسِكْ بِنِصَالِهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{3777}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin 'Abdullah said:"A man passed through the masjid with some arrows, and the Messenger of Allah(ﷺ) said: 'Hold them by their heads!' He said: 'Yes(ok)}}
\hadithdefcmd{ibnmajah}{3778}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا مَرَّ أَحَدُكُمْ فِي مَسْجِدِنَا أَوْ فِي سُوقِنَا وَمَعَهُ نَبْلٌ فَلْيُمْسِكْ عَلَى نِصَالِهَا بِكَفِّهِ أَنْ تُصِيبَ أَحَدًا مِنَ الْمُسْلِمِينَ بِشَىْءٍ أَوْ فَلْيَقْبِضْ عَلَى نِصَالِهَا ‏"‏ ‏.‏\hadithno{3778}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Prophet(ﷺ) said:"When anyone of you passes through our masjid or our marketplace carrying arrows, let him hold them by their heads, lest he hurt any Muslims}}
\hadithdefcmd{ibnmajah}{3779}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمَاهِرُ بِالْقُرْآنِ مَعَ السَّفَرَةِ الْكِرَامِ الْبَرَرَةِ وَالَّذِي يَقْرَؤُهُ يَتَتَعْتَعُ فِيهِ وَهُوَ عَلَيْهِ شَاقٌّ لَهُ أَجْرَانِ اثْنَانِ ‏"‏ ‏.‏\hadithno{3779}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aisha that the Messenger of Allah (ﷺ) said:"The one who is proficient with the Qur'an will be with the noble and righteous scribes (the angels), and the one who reads it and stumbles over it, finding it difficult, will have two rewards}}
\hadithdefcmd{ibnmajah}{3780}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا شَيْبَانُ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُقَالُ لِصَاحِبِ الْقُرْآنِ إِذَا دَخَلَ الْجَنَّةَ اقْرَأْ وَاصْعَدْ ‏.‏ فَيَقْرَأُ وَيَصْعَدُ بِكُلِّ آيَةٍ دَرَجَةً حَتَّى يَقْرَأَ آخِرَ شَىْءٍ مَعَهُ ‏"‏ ‏.‏\hadithno{3780}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa`eed Al-Khudri that the Messenger of Allah (ﷺ) said:"It will be said to the companion of the Qur'an, when he enters Paradise: 'Recite and rise one degree for every Verse,' until he recites the last thing that he knows}}
\hadithdefcmd{ibnmajah}{3781}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ بَشِيرِ بْنِ مُهَاجِرٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَجِيءُ الْقُرْآنُ يَوْمَ الْقِيَامَةِ كَالرَّجُلِ الشَّاحِبِ فَيَقُولُ أَنَا الَّذِي أَسْهَرْتُ لَيْلَكَ وَأَظْمَأْتُ نَهَارَكَ ‏"‏ ‏.‏\hadithno{3781}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Buraidah that his father told that the Messenger of Allah(ﷺ) said:"The Quran will come on the Day of Resurrection, like a pale man, and will say: 'I am the one that kept you awake at night and made you thirsty during the day}}
\hadithdefcmd{ibnmajah}{3782}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَيُحِبُّ أَحَدُكُمْ إِذَا رَجَعَ إِلَى أَهْلِهِ أَنْ يَجِدَ فِيهِ ثَلاَثَ خَلِفَاتٍ عِظَامٍ سِمَانٍ ‏"‏ ‏.‏ قُلْنَا نَعَمْ ‏.‏ قَالَ ‏"‏ فَثَلاَثُ آيَاتٍ يَقْرَؤُهُنَّ أَحَدُكُمْ فِي صَلاَتِهِ خَيْرٌ لَهُ مِنْ ثَلاَثِ خَلِفَاتٍ سِمَانٍ عِظَامٍ ‏"‏ ‏.‏\hadithno{3782}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah(ﷺ) said:"Wouldn't anyone of you like to find three great, fat pregnant she-camels when he returns to his family?" We said: "Yes." He said: "Three verses that one of you recites during the praer are better for him than three great, fat pregnant she-camels}}
\hadithdefcmd{ibnmajah}{3783}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَثَلُ الْقُرْآنِ مَثَلُ الإِبِلِ الْمُعَقَّلَةِ إِنْ تَعَاهَدَهَا صَاحِبُهَا بِعُقُلِهَا أَمْسَكَهَا عَلَيْهِ وَإِنْ أَطْلَقَ عُقُلَهَا ذَهَبَتْ ‏"‏ ‏.‏\hadithno{3783}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Umar that the Messenger of Allah(ﷺ) said:"The likeness of the Quran is that of a hobbled camel. If its owner ties its rope, he will keep it, but if he loosens its rope it will go away}}
\hadithdefcmd{ibnmajah}{3784}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ قَالَ اللَّهُ عَزَّ وَجَلَّ قَسَمْتُ الصَّلاَةَ بَيْنِي وَبَيْنَ عَبْدِي شَطْرَيْنِ فَنِصْفُهَا لِي وَنِصْفُهَا لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ اقْرَءُوا يَقُولُ الْعَبْدُ ‏\{الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ\}‏ فَيَقُولُ اللَّهُ عَزَّ وَجَلَّ حَمِدَنِي عَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏.‏ فَيَقُولُ ‏\{الرَّحْمَنِ الرَّحِيمِ\}‏ فَيَقُولُ أَثْنَى عَلَىَّ عَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏.‏ يَقُولُ ‏\{مَالِكِ يَوْمِ الدِّينِ \}‏ فَيَقُولُ اللَّهُ مَجَّدَنِي عَبْدِي فَهَذَا لِي وَهَذِهِ الآيَةُ بَيْنِي وَبَيْنَ عَبْدِي نِصْفَيْنِ يَقُولُ الْعَبْدُ ‏\{إِيَّاكَ نَعْبُدُ وَإِيَّاكَ نَسْتَعِينُ\}‏ يَعْنِي فَهَذِهِ بَيْنِي وَبَيْنَ عَبْدِي وَلِعَبْدِي مَا سَأَلَ وَآخِرُ السُّورَةِ لِعَبْدِي يَقُولُ الْعَبْدُ ‏\{اهْدِنَا الصِّرَاطَ الْمُسْتَقِيمَ * صِرَاطَ الَّذِينَ أَنْعَمْتَ عَلَيْهِمْ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ\}‏ فَهَذَا لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏\hadithno{3784}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said, 'I heard the Messenger of Allah(ﷺ) say':"Allah said: 'I have divided the prayer between Myself and My slave into two halves, and My slave shall have what he has asked for.'When the slave says: 'Al-hamdulillah i rabbil Alameen (All the praise is to Allah, the Lord of all that exists),' Allah says:'My slave has praised Me, and My slave shall have what he has asked for.' And when he says: 'Ar-Rahmanir-Rahim (The Mos Gracious, the Most Merciful),' Allah says: 'My slave has extolled Me, and My slave shall have what he has asked for.' And when he says: 'Maliki yawmiddin [The Only Owner (and he Ruling Judge] if the Day of Recompense],' Allahs says: 'My slave has Glorified Me. This is for Me, and this Verse is between me and My slave in two halves.' And when he says: ' Iyyaka na'budu wa iyyaka nastain [You (Alone) we worship, and You (Alone) we ask for help],' He says: 'This is between Me an My slave, and My slave shall have what he has asked for.' And the end of the Surah is for My slave.' And when he says: 'Ihdinas-siratal-mustaqeema, siratal-alldhina an'amta alayhim a lad-dallin [Guide us to the Straight Way, the way of those on whom You have bestowed Your Grace, not(the way) of those who earned Your Anger, nor of those who went astray],' He says: 'THis is for My slave, and My slave shall have what he has asked for}}
\hadithdefcmd{ibnmajah}{3785}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَلاَ أُعَلِّمُكَ أَعْظَمَ سُورَةٍ فِي الْقُرْآنِ قَبْلَ أَنْ أَخْرُجَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالَ فَذَهَبَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لِيَخْرُجَ فَأَذْكَرْتُهُ فَقَالَ ‏"‏ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ\}‏ وَهِيَ السَّبْعُ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ الَّذِي أُوتِيتُهُ ‏"‏ ‏.‏\hadithno{3785}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa'eed bin Mu'alla said:"The Messenger of Allah(ﷺ) said to me: 'Shall I not teach you the greatest Surah in the QUran before I leave the masjid?' Then the Propeht(ﷺ) went to leave, so I reminded him, and he said: Al-hamdulillahi Rabbil-Alameen (All the praise is to Allah, the Lord of all that exists). It is the Seven Oft-Recited Verses, and it is the Grand Quran that has been given to me}}
\hadithdefcmd{ibnmajah}{3786}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ عَبَّاسٍ الْجُشَمِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ إِنَّ سُورَةً فِي الْقُرْآنِ ثَلاَثُونَ آيَةً شَفَعَتْ لِصَاحِبِهَا حَتَّى غُفِرَ لَهُ ‏\{تَبَارَكَ الَّذِي بِيَدِهِ الْمُلْكُ\}‏ ‏"‏ ‏.‏\hadithno{3786}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"There is a surah in the Qur'an, with thirty verses, which will intercede for its companion (the one who recites it) until he is forgiven: Tabarakal-ladhi bi yadihil mulk (Blessed is He in Whose Hand is the Dominion)}}
\hadithdefcmd{ibnmajah}{3787}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ\}‏ تَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3787}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said that the Messenger of Allah(ﷺ) said:"Qul Huwa Allahu ahad [Say: He is Allah, (the) One] is equivalent to one third of the Quran}}
\hadithdefcmd{ibnmajah}{3788}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ‏\{قُلْ هُوَ اللَّهُ أَحَدٌ\}‏ تَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3788}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah(ﷺ) said: Qul Huwa Allahu ahad [Say: He is Allah, (the) One] is equivalent to one third of the Quran}}
\hadithdefcmd{ibnmajah}{3789}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي قَيْسٍ الأَوْدِيِّ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُ أَحَدٌ الْوَاحِدُ الصَّمَدُ تَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3789}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Masud Al Ansari said:"The Messenger of Allah(ﷺ) said: "Allahu ahad, Al-Wahidus-Samad [Allah (the) One, the One the Self-Sufficient Master] is equivalent to one third of the Quran}}
\hadithdefcmd{ibnmajah}{3790}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ زِيَادِ بْنِ أَبِي زِيَادٍ، مَوْلَى ابْنِ عَيَّاشٍ عَنْ أَبِي بَحْرِيَّةَ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ أَلاَ أُنَبِّئُكُمْ بِخَيْرِ أَعْمَالِكُمْ وَأَرْضَاهَا عِنْدَ مَلِيكِكُمْ وَأَرْفَعِهَا فِي دَرَجَاتِكُمْ وَخَيْرٍ لَكُمْ مِنْ إِعْطَاءِ الذَّهَبِ وَالْوَرِقِ وَمِنْ أَنْ تَلْقَوْا عَدُوَّكُمْ فَتَضْرِبُوا أَعْنَاقَهُمْ وَيَضْرِبُوا أَعْنَاقَكُمْ ‏"‏ ‏.‏ قَالُوا وَمَا ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ذِكْرُ اللَّهِ ‏"‏ ‏.‏ وَقَالَ مُعَاذُ بْنُ جَبَلٍ مَا عَمِلَ امْرُؤٌ بِعَمَلٍ أَنْجَى لَهُ مِنْ عَذَابِ اللَّهِ عَزَّ وَجَلَّ مِنْ ذِكْرِ اللَّهِ ‏.‏\hadithno{3790}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Darda that the Prophet(ﷺ) said:"Shall I not tell you of the best of your deeds, the most pleasing to your Sovereign, those that raise you most in status, that are better than your gold and silver, or meeting you enemy (in battle) and you strike their necks and they strike your necks?" They said: " WHat is that, O Messenger of Allah?" He said: "Remembering Allah(Dhikr)}}
\hadithdefcmd{ibnmajah}{3791}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، عَنْ أَبِي هُرَيْرَةَ، وَأَبِي، سَعِيدٍ يَشْهَدَانِ بِهِ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا جَلَسَ قَوْمٌ مَجْلِسًا يَذْكُرُونَ اللَّهَ فِيهِ إِلاَّ حَفَّتْهُمُ الْمَلاَئِكَةُ وَتَغَشَّتْهُمُ الرَّحْمَةُ وَتَنَزَّلَتْ عَلَيْهِمُ السَّكِينَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ ‏"‏ ‏.‏\hadithno{3791}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah and Abu Sa'eed bore witness that the Prophet(ﷺ) said:"No people sit in a gathering remembering Allah, But the angels surround them, mercy covers them, tranquility descends upon them and Allah remembers them before those who are with Him}}
\hadithdefcmd{ibnmajah}{3792}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، عَنِ الأَوْزَاعِيِّ، عَنْ إِسْمَاعِيلَ بْنِ عُبَيْدِ اللَّهِ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَقُولُ أَنَا مَعَ عَبْدِي إِذَا هُوَ ذَكَرَنِي وَتَحَرَّكَتْ بِي شَفَتَاهُ ‏"‏ ‏.‏\hadithno{3792}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet(ﷺ) said:"Allah says: 'I am with My slave when he remembers Me and his lips move saying My Name}}
\hadithdefcmd{ibnmajah}{3793}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، أَخْبَرَنِي عَمْرُو بْنُ قَيْسٍ الْكِنْدِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، أَنَّ أَعْرَابِيًّا، قَالَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِنَّ شَرَائِعَ الإِسْلاَمِ قَدْ كَثُرَتْ عَلَىَّ فَأَنْبِئْنِي مِنْهَا بِشَىْءٍ أَتَشَبَّثُ بِهِ ‏.‏ قَالَ ‏ "‏ لاَ يَزَالُ لِسَانُكَ رَطْبًا مِنْ ذِكْرِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3793}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abdullah bin Busr that a Bedouin said to the Messenger of Allah(ﷺ) said:"The laws of Islam are burdensome for me. Tell me of something that I will be able to adhere to. He said: 'Always keep your tongue moist with the remembrance of Allah, the Mighty and Sublime}}
\hadithdefcmd{ibnmajah}{3794}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ حَمْزَةَ الزَّيَّاتِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، أَنَّهُ شَهِدَ عَلَى أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ أَنَّهُمَا شَهِدَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا قَالَ الْعَبْدُ لاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ‏.‏ قَالَ يَقُولُ اللَّهُ عَزَّ وَجَلَّ صَدَقَ عَبْدِي لاَ إِلَهَ إِلاَّ أَنَا وَأَنَا أَكْبَرُ ‏.‏ وَإِذَا قَالَ الْعَبْدُ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ ‏.‏ قَالَ صَدَقَ عَبْدِي لاَ إِلَهَ إِلاَّ أَنَا وَحْدِي ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ لاَ شَرِيكَ لَهُ ‏.‏ قَالَ صَدَقَ عَبْدِي لاَ إِلَهَ إِلاَّ أَنَا وَلاَ شَرِيكَ لِي ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ ‏.‏ قَالَ صَدَقَ عَبْدِي لاَ إِلَهَ إِلاَّ أَنَا لِيَ الْمُلْكُ وَلِيَ الْحَمْدُ ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ قَالَ صَدَقَ عَبْدِي لاَ إِلَهَ إِلاَّ أَنَا وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِي ‏"‏ ‏.‏ قَالَ أَبُو إِسْحَاقَ ثُمَّ قَالَ الأَغَرُّ شَيْئًا لَمْ أَفْهَمْهُ ‏.‏ قَالَ فَقُلْتُ لأَبِي جَعْفَرٍ مَا قَالَ فَقَالَ مَنْ رُزِقَهُنَّ عِنْدَ مَوْتِهِ لَمْ تَمَسَّهُ النَّارُ ‏.‏\hadithno{3794}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah and Abu Saeed bore witness that the Messenger of Allah(ﷺ) said:"If a person says: 'La ilaha illallahu wa Allahu Akbar (None has the right to be worshipped but Allah and Allah is the Most Great),'Allah says: 'My slave has spoken the truth; there is none worthy of worship except I, and I am the Most Great.' If a person says: La ilaha Illallah wahdahu (There is none worthy of worship except Allah alone), Allah says: 'My slave has spoken the truth; there is none worthy of worship except I, alone.' If he says, La ilaha illallahu la sharikalahu (There is none worthy of worship except Allah with no partner or associate),' Allah says: 'My slave has spoken the truth; there is none worthy of worship except I, with no partner or associate.' If he says: 'La illah illallah, lahul mulku wa lahul hamdu (There is none worthy of worship except Allah, all dominion is His and all praise is to Him),' Allah says: 'My slave has spoken the truth; there is none of worthy of worship except I, all dominion Mine and all praise is due to Me.' If he says: ' La illaha illallah, la hawla wa la quwwata illa billah (There is none worthy of worship and there is no power and no strength except with Allah),' Allah says: 'My slave has spoken then truth; there is none worthy of worship except I, and tehre is no power and no strength except with Me.' One of the narrators Abu Ishaq said: "Then Agharr (another narrator) said something that I did not understand. I said to Abu Jafar: 'What did he say?' He said: 'Whoever is blessed with (the ability to say) them (these words) at the time of death, the Fire will not touch him}}
\hadithdefcmd{ibnmajah}{3795}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْوَهَّابِ، عَنْ مِسْعَرٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ يَحْيَى بْنِ طَلْحَةَ، عَنْ أُمِّهِ، سُعْدَى الْمُرِّيَّةِ قَالَتْ مَرَّ عُمَرُ بِطَلْحَةَ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ مَا لَكَ مُكْتَئِبًا أَسَاءَتْكَ إِمْرَةُ ابْنِ عَمِّكَ قَالَ لاَ وَلَكِنْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنِّي لأَعْلَمُ كَلِمَةً لاَ يَقُولُهَا أَحَدٌ عِنْدَ مَوْتِهِ إِلاَّ كَانَتْ نُورًا لِصَحِيفَتِهِ وَإِنَّ جَسَدَهُ وَرُوحَهُ لَيَجِدَانِ لَهَا رَوْحًا عِنْدَ الْمَوْتِ ‏"‏ ‏.‏ فَلَمْ أَسْأَلْهُ حَتَّى تُوُفِّيَ ‏.‏ قَالَ أَنَا أَعْلَمُهَا هِيَ الَّتِي أَرَادَ عَمَّهُ عَلَيْهَا وَلَوْ عَلِمَ أَنَّ شَيْئًا أَنْجَى لَهُ مِنْهَا لأَمَرَهُ ‏.‏\hadithno{3795}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Yahya bin Talha that :his mother Su'da Al-Murriyyah said: "Umar bin Khattab passed by Talhah, after the Messenger of Allah(ﷺ) had died, and said: 'Why do you look so sad? Are you upset because your cousin has been appointed leader?' He said: 'No, but I heard the Messenger of Allah(ﷺ) say: "I know a word which no one says at the time of death but it will be light in his record of deeds, and his body and soul will find comfort in it at the time of death," -but I did not ask him about it before he died.' He ('Umar) said: ' I know what it is. It is what he wanted his uncle (Abu Talib) to say, and if he had known anything that would be more effective in saving him, he would have told him to say it}}
\hadithdefcmd{ibnmajah}{3796}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ يُونُسَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ هِصَّانَ بْنِ الْكَاهِلِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ نَفْسٍ تَمُوتُ تَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَرْجِعُ ذَلِكَ إِلَى قَلْبٍ مُوقِنٍ إِلاَّ غَفَرَ اللَّهُ لَهَا ‏"‏ ‏.‏\hadithno{3796}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mu'adh bin Jabal that the :Messenger of Allah(ﷺ) said: "There is no soul that died bearing witness to La ilaha illallah, and that I am the Messenger of Allah, from the heart with certainity, but Allah will forgive it}}
\hadithdefcmd{ibnmajah}{3797}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا زَكَرِيَّا بْنُ مَنْظُورٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عُقْبَةَ، عَنْ أُمِّ هَانِئٍ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ لاَ يَسْبِقُهَا عَمَلٌ وَلاَ تَتْرُكُ ذَنْبًا ‏"‏ ‏.‏\hadithno{3797}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Hani' said:"The Messenger of Allah(ﷺ) said: (About saying) La ilaha illah - no deed takes precedence over it and it does not leave any sin}}
\hadithdefcmd{ibnmajah}{3798}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مَالِكِ بْنِ أَنَسٍ، أَخْبَرَنِي سُمَىٌّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ قَالَ فِي يَوْمٍ مِائَةَ مَرَّةٍ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ كَانَ لَهُ عَدْلَ عَشْرِ رِقَابٍ وَكُتِبَتْ لَهُ مِائَةُ حَسَنَةٍ وَمُحِيَ عَنْهُ مِائَةُ سَيِّئَةٍ وَكُنَّ لَهُ حِرْزًا مِنَ الشَّيْطَانِ سَائِرَ يَوْمِهِ إِلَى اللَّيْلِ وَلَمْ يَأْتِ أَحَدٌ بِأَفْضَلَ مِمَّا أَتَى بِهِ إِلاَّ مَنْ قَالَ أَكْثَرَ ‏"‏ ‏.‏\hadithno{3798}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah(ﷺ) said: "Whoever says one hundered times each day: La ilaha illahu wahdahu la sharikalahu, wa lahul-mulku wa lahul hamduwa huwa ala kulli shayin qadeer (None has the right to be worshipped but Allah alone, with no partner or associate. His is the dominion, all praise is to Him, and He is able to do all things), it will be equivalent to him freeing ten slaves, and one hundered merits will be recorded for him, and one hundered bad deeds will be erased from (his record), and it will be a protection for him against Satan all day until night comes. No one can do anything better then him except one who says more}}
\hadithdefcmd{ibnmajah}{3799}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ الْمُخْتَارِ، عَنْ مُحَمَّدِ بْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ قَالَ فِي دُبُرِ صَلاَةِ الْغَدَاةِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ بِيَدِهِ الْخَيْرُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ - كَانَ كَعَتَاقِ رَقَبَةٍ مِنْ وَلَدِ إِسْمَاعِيلَ ‏"‏ ‏.‏\hadithno{3799}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Saeed that :the Prophet(ﷺ) said: "Whoever says, following the morning prayer: La ilaha illallahu wahdahu la sahrikalau, lahul mulku wa lahul hamdu, bi yadihil khair, wa huwa ala kulli shay'in qadir (None has the right to be worshipped but Allah alone, with no partner or associate. His is the dominion, all praise is to Him, in His Hand is all goodness, and He is Able to do all things), it will be as if he freed slave from among the sons of Isma'il}}
\hadithdefcmd{ibnmajah}{3800}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا مُوسَى بْنُ إِبْرَاهِيمَ بْنِ كَثِيرِ بْنِ بَشِيرِ بْنِ الْفَاكِهِ، قَالَ سَمِعْتُ طَلْحَةَ بْنَ خِرَاشٍ ابْنَ عَمِّ، جَابِرٍ قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ أَفْضَلُ الذِّكْرِ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَفْضَلُ الدُّعَاءِ الْحَمْدُ لِلَّهِ ‏"‏ ‏.‏\hadithno{3800}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin 'Abdullah said:"I heard the Messenger of Allah (ﷺ) say: 'The best of remembrance is La ilaha illallah (None has the right to be worshipped but Allah), and the best of supplication is Al-Hamdu Lillah (praise is to Allah)}}
\hadithdefcmd{ibnmajah}{3801}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا صَدَقَةُ بْنُ بَشِيرٍ، مَوْلَى الْعُمَرِيِّينَ قَالَ سَمِعْتُ قُدَامَةَ بْنَ إِبْرَاهِيمَ الْجُمَحِيَّ، يُحَدِّثُ أَنَّهُ كَانَ يَخْتَلِفُ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ وَهُوَ غُلاَمٌ وَعَلَيْهِ ثَوْبَانِ مُعَصْفَرَانِ قَالَ فَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ حَدَّثَهُمْ ‏ "‏ أَنَّ عَبْدًا مِنْ عِبَادِ اللَّهِ قَالَ يَا رَبِّ لَكَ الْحَمْدُ كَمَا يَنْبَغِي لِجَلاَلِ وَجْهِكَ وَلِعَظِيمِ سُلْطَانِكَ فَعَضَّلَتْ بِالْمَلَكَيْنِ فَلَمْ يَدْرِيَا كَيْفَ يَكْتُبَانِهَا فَصَعِدَا إِلَى السَّمَاءِ وَقَالاَ يَا رَبَّنَا إِنَّ عَبْدَكَ قَدْ قَالَ مَقَالَةً لاَ نَدْرِي كَيْفَ نَكْتُبُهَا ‏.‏ قَالَ اللَّهُ عَزَّ وَجَلَّ وَهُوَ أَعْلَمُ بِمَا قَالَ عَبْدُهُ مَاذَا قَالَ عَبْدِي قَالاَ يَا رَبِّ إِنَّهُ قَالَ يَا رَبِّ لَكَ الْحَمْدُ كَمَا يَنْبَغِي لِجَلاَلِ وَجْهِكَ وَعَظِيمِ سُلْطَانِكَ ‏.‏ فَقَالَ اللَّهُ عَزَّ وَجَلَّ لَهُمَا اكْتُبَاهَا كَمَا قَالَ عَبْدِي حَتَّى يَلْقَانِي فَأَجْزِيَهُ بِهَا ‏"‏ ‏.‏\hadithno{3801}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that :the Messenger of Allah (ﷺ) told them: "One of the slaves of Allah said: 'Ya Rabb! Lakal-hamdu kama yanbagi li-jalali Wajhika wa li 'azima sultanika (O Lord, to You is praise as befits the Glory of Your Face and the greatness of Your Might.)' The angels were uncertain and did not know how to write this down, so they ascended to heaven and said: 'O our Lord, Your slave has said a word that we do not know how to write down.' Allah said - and He knows best what His slave said - 'What did My slave say?' They said: 'O Lord, he said "Ya Rabb! Lakal-hamdu kama yanbagi li-jalali Wajhika wa li'azima sultanika (O Lord, to You is praise as befits the Glory of Your Face and the greatness of your Might).'" Allah said to them: 'Write it down as My slave said it, until he meets Me and I shall reward him for it}}
\hadithdefcmd{ibnmajah}{3802}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الْجَبَّارِ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ رَجُلٌ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ ‏.‏ فَلَمَّا صَلَّى النَّبِيُّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ مَنْ ذَا الَّذِي قَالَ هَذَا ‏"‏ ‏.‏ قَالَ الرَّجُلُ أَنَا وَمَا أَرَدْتُ إِلاَّ الْخَيْرَ ‏.‏ فَقَالَ ‏"‏ لَقَدْ فُتِحَتْ لَهَا أَبْوَابُ السَّمَاءِ فَمَا نَهْنَهَهَا شَىْءٌ دُونَ الْعَرْشِ ‏"‏ ‏.‏\hadithno{3802}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdul-Jabbar bin Wa'il that :his father said: "I prayed with the Prophet (ﷺ) and a man said: 'Alhamdu lillahi hamdan kathiran tayyiban mubarakan fihi (Praise is to Allah, much, good and blessed praise).' When the Prophet (ﷺ) finished praying, he said: 'Who said that?' The man said: 'It was me, but I did not mean anything but good.' He said: 'The gates of heaven were opened because of it and nothing prevented it from reaching the Throne}}
\hadithdefcmd{ibnmajah}{3803}{حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ الأَزْرَقُ أَبُو مَرْوَانَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، عَنْ مَنْصُورِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا رَأَى مَا يُحِبُّ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي بِنِعْمَتِهِ تَتِمُّ الصَّالِحَاتُ ‏"‏ ‏.‏ وَإِذَا رَأَى مَا يَكْرَهُ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ ‏"‏ ‏.‏\hadithno{3803}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah (ﷺ) saw something he liked, he would say: 'Al-hamdu lillahil-ladhi bi ni'matihi tatimmus-salihat (Praise is to Allah by Whose grace good deeds are completed).' And if he saw something that he disliked, he would say: 'Al-hamdu lillahi 'ala kulli hal (Praise is to Allah in all circumstances)}}
\hadithdefcmd{ibnmajah}{3804}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ ‏ "‏ الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ رَبِّ أَعُوذُ بِكَ مِنْ حَالِ أَهْلِ النَّارِ ‏"‏ ‏.‏\hadithno{3804}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narratd from Abu Hurairah that :the Prophet (ﷺ) used to say: "Al-hamdu lillahi 'ala kulli hal. Rabbi a'udhu bika min hali ahlin-nar (Praise is to Allah in all circumstances, O Allah, I seek refuge with You from the situation of the people of Hell)}}
\hadithdefcmd{ibnmajah}{3805}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ شَبِيبِ بْنِ بِشْرٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا أَنْعَمَ اللَّهُ عَلَى عَبْدٍ نِعْمَةً فَقَالَ الْحَمْدُ لِلَّهِ ‏.‏ إِلاَّ كَانَ الَّذِي أَعْطَاهُ أَفْضَلَ مِمَّا أَخَذَ ‏"‏ ‏.‏\hadithno{3805}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that :the Messenger of Allah (ﷺ) said: 'Allah does not bestow a blessing upon any slave and he says: 'Al-hamdu Lillah (praise is to Allah),' except that what he gives (the praise) is better than what he received (the blessing)}}
\hadithdefcmd{ibnmajah}{3806}{حَدَّثَنَا أَبُو بِشْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كَلِمَتَانِ خَفِيفَتَانِ عَلَى اللِّسَانِ ثَقِيلَتَانِ فِي الْمِيزَانِ حَبِيبَتَانِ إِلَى الرَّحْمَنِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ سُبْحَانَ اللَّهِ الْعَظِيمِ ‏"‏ ‏.‏\hadithno{3806}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (ﷺ) said: 'Two words which are light on the tongue and heavy in the Balance, and beloved to the Most Merciful: Subhan-Allah wa bi hamdihi, Subhan-Allahil-'Azim (Glory and praise is to Allah, glory is to Allah the Almighty)}}
\hadithdefcmd{ibnmajah}{3807}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي سِنَانٍ، عَنْ عُثْمَانَ بْنِ أَبِي سَوْدَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ بِهِ وَهُوَ يَغْرِسُ غَرْسًا فَقَالَ ‏"‏ يَا أَبَا هُرَيْرَةَ مَا الَّذِي تَغْرِسُ ‏"‏ ‏.‏ قُلْتُ غِرَاسًا لِي ‏.‏ قَالَ ‏"‏ أَلاَ أَدُلُّكَ عَلَى غِرَاسٍ خَيْرٍ لَكَ مِنْ هَذَا ‏"‏ ‏.‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قُلْ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ يُغْرَسْ لَكَ بِكُلِّ وَاحِدَةٍ شَجَرَةٌ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{3807}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (ﷺ) passed by him when he was planting a plant, and said: "O Abu Hurairah, what are you planting?" I said: "A plant for me." He said: "Shall I not tell you of a plant that is better than this?" He said: "Of course, O Messenger of Allah." He said: "Say: 'Subhan-Allah, wal-hamdu-lillah, wa la ilaha illallah, wa Allahu Akbar (Glory is to Allah, praise is to Allah, none has the right to be worshiped but Allah and Allah is the Most Great.)' For each one a tree will be planted for you in Paradise}}
\hadithdefcmd{ibnmajah}{3808}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي رِشْدِينَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ جُوَيْرِيَةَ، قَالَتْ مَرَّ بِهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ صَلَّى الْغَدَاةَ أَوْ بَعْدَ مَا صَلَّى الْغَدَاةَ وَهِيَ تَذْكُرُ اللَّهَ فَرَجَعَ حِينَ ارْتَفَعَ النَّهَارُ - أَوْ قَالَ انْتَصَفَ - وَهِيَ كَذَلِكَ فَقَالَ ‏ "‏ لَقَدْ قُلْتُ مُنْذُ قُمْتُ عَنْكِ أَرْبَعَ كَلِمَاتٍ ثَلاَثَ مَرَّاتٍ هِيَ أَكْثَرُ وَأَرْجَحُ - أَوْ أَوْزَنُ - مِمَّا قُلْتِ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ ‏"‏ ‏.‏\hadithno{3808}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Juwairiyah said:"The Messenger of Allah (ﷺ) passed by her when he prayed the morning prayer, or after he prayed the morning prayer, and she was remembering Allah. He came back when the sun had risen" - or he (one of the narrators) said, "at midday - and she was still doing that. He said: 'I have said four words, three times, since I left you, and they are greater and weigh more heavily than what you have said. They are: Subhan-Allahi 'adada khalqiha, Subhan-Allahi rida nafsihi, Subhan-Allahi zinata 'arshihi, Subhan-Allah midada kalimatihi (Glory is to Allah, as much as the number of His creation, glory is to Allah as much as pleases Him, glory is to Allah as much as the weight of His Throne, glory is to Allah as much as the ink of His words)}}
\hadithdefcmd{ibnmajah}{3809}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ مُوسَى بْنِ أَبِي عِيسَى الطَّحَّانِ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَوْ عَنْ أَخِيهِ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِمَّا تَذْكُرُونَ مِنْ جَلاَلِ اللَّهِ التَّسْبِيحَ وَالتَّهْلِيلَ وَالتَّحْمِيدَ يَنْعَطِفْنَ حَوْلَ الْعَرْشِ لَهُنَّ دَوِيٌّ كَدَوِيِّ النَّحْلِ تُذَكِّرُ بِصَاحِبِهَا أَمَا يُحِبُّ أَحَدُكُمْ أَنْ يَكُونَ لَهُ - أَوْ لاَ يَزَالَ لَهُ - مَنْ يُذَكِّرُ بِهِ ‏"‏ ‏.‏\hadithno{3809}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Nu'man bin Bashir that :the Messenger of Allah (ﷺ) said: "What you mention of glory of Allah, of Tabsih (Subhan-Allah), Tahlil (Allahu-Akbar) and Tahmid (Al-Hamdu lillah), revolves around the Throne, buzzing like bees, reminding of the one who said it. Wouldn't any one of you like to have, or continue to have, something that reminds of him (in the presence of Allah)?}}
\hadithdefcmd{ibnmajah}{3810}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا أَبُو يَحْيَى، زَكَرِيَّا بْنُ مَنْظُورٍ حَدَّثَنِي مُحَمَّدُ بْنُ عُقْبَةَ بْنِ أَبِي مَالِكٍ، عَنْ أُمِّ هَانِئٍ، قَالَتْ أَتَيْتُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ دُلَّنِي عَلَى عَمَلٍ فَإِنِّي قَدْ كَبِرْتُ وَضَعُفْتُ وَبَدَّنْتُ ‏.‏ فَقَالَ ‏ "‏ كَبِّرِي اللَّهَ مِائَةَ مَرَّةٍ وَاحْمَدِي اللَّهَ مِائَةَ مَرَّةٍ وَسَبِّحِي اللَّهَ مِائَةَ مَرَّةٍ خَيْرٌ مِنْ مِائَةِ فَرَسٍ مُلْجَمٍ مُسْرَجٍ فِي سَبِيلِ اللَّهِ وَخَيْرٌ مِنْ مِائَةِ بَدَنَةٍ وَخَيْرٌ مِنْ مِائَةِ رَقَبَةٍ ‏"‏ ‏.‏\hadithno{3810}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Hani' said:"I came to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, tell me of a (good) deed, for I have become old and weak and overweight.' He said: 'Proclaim the greatness of Allah (say Allahu Akbar) one hundred times, praise Allah (say Al-Hamdu Lillah) one hundred times, and glorify Allah (say Subhan-Allah) one hundred times. (That is) better than one hundred horses bridled and saddled for the sake of Allah, better than one hundred sacrificial camels, and better than (freeing) one hundred slaves}}
\hadithdefcmd{ibnmajah}{3811}{حَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ عَمْرٍو حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَرْبَعٌ أَفْضَلُ الْكَلاَمِ لاَ يَضُرُّكَ بِأَيِّهِنَّ بَدَأْتَ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ‏"‏ ‏.‏\hadithno{3811}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Samurah bin Jundab that :the Prophet (ﷺ) said: "(There are) four that are the best of words, and it does not matter with which you begin: Subhan-Allah, wal-Hamdu-Lillah, wa la ilaha illallah, wa Allahu Akbar (Glory is to Allah, praise is to Allah, none has the right to be worshiped but Allah and Allah is the Most Great)}}
\hadithdefcmd{ibnmajah}{3812}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْوَشَّاءُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ قَالَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ غُفِرَتْ لَهُ ذُنُوبُهُ وَلَوْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{3812}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (ﷺ) said: "Whoever says: Subhan Allahi wa bi hamdihi (Glory and praise is to Allah) one hundred times, his sins will be forgiven even if they were like the foam of the sea}}
\hadithdefcmd{ibnmajah}{3813}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عُمَرَ بْنِ رَاشِدٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عَلَيْكَ بِسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ فَإِنَّهَا - يَعْنِي - يَحْطُطْنَ الْخَطَايَا كَمَا تَحُطُّ الشَّجَرَةُ وَرَقَهَا ‏"‏ ‏.‏\hadithno{3813}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Darda' said:"The Messenger of Allah (ﷺ) said to me: 'You should recite Subhan-Allah, wal-Hamdu-Lillah, wa la ilahah illallah, wa Allahu Akbar (Glory is to Allah, praise is to Allah, none has the right to be worshiped but Allah, and Allah is the Most Great), for it sheds sins like the tree sheds its leaves}}
\hadithdefcmd{ibnmajah}{3814}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، وَالْمُحَارِبِيُّ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ إِنْ كُنَّا لَنَعُدُّ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْمَجْلِسِ يَقُولُ ‏ "‏ رَبِّ اغْفِرْ لِي وَتُبْ عَلَىَّ إِنَّكَ أَنْتَ التَّوَّابُ الرَّحِيمُ ‏"‏ ‏.‏ مِائَةَ مَرَّةٍ ‏.‏\hadithno{3814}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn `Umar said:"We used to count that the Messenger of Allah (ﷺ) said one hundred times in a gathering: 'Rabbighfirli wa tub `alayya innaka Antat-Tawwabur-Rahim (O Allah forgive me and accept my repentance, for You are the Accepter of repentance, the Most Merciful)}}
\hadithdefcmd{ibnmajah}{3815}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لأَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ فِي الْيَوْمِ مِائَةَ مَرَّةٍ ‏"‏ ‏.‏\hadithno{3815}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: 'I seek the forgiveness of Allah and repent to Him one hundred times each day}}
\hadithdefcmd{ibnmajah}{3816}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مُغِيرَةَ بْنِ أَبِي الْحُرِّ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنِّي لأَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ فِي الْيَوْمِ سَبْعِينَ مَرَّةً ‏"‏ ‏.‏\hadithno{3816}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sa'eed bin Abu Burdah bin Abu Musa, from his father, that :his grandfather said: "The Messenger of Allah (saas) said: 'I seek the forgivenenss of Allah and repent to Him seventy times each day}}
\hadithdefcmd{ibnmajah}{3817}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الْمُغِيرَةِ، عَنْ حُذَيْفَةَ، قَالَ كَانَ فِي لِسَانِي ذَرَبٌ عَلَى أَهْلِي وَكَانَ لاَ يَعْدُوهُمْ إِلَى غَيْرِهِمْ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ أَيْنَ أَنْتَ مِنَ الاِسْتِغْفَارِ تَسْتَغْفِرُ اللَّهَ فِي الْيَوْمِ سَبْعِينَ مَرَّةً ‏"‏ ‏.‏\hadithno{3817}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Hudhaifah said:"I was harsh in the way I spoke to my family, but not to others. I mentioned that to the Prophet (saas) and he said: 'Why don't you ask for forgiveness? Ask Allah to forgive you, seventy times each day}}
\hadithdefcmd{ibnmajah}{3818}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عِرْقٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ بُسْرٍ، يَقُولُ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ طُوبَى لِمَنْ وَجَدَ فِي صَحِيفَتِهِ اسْتِغْفَارًا كَثِيرًا ‏"‏ ‏.‏\hadithno{3818}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Busr said that :the Prophet (saas) said: "Glad tidings to those who find a lot of seeking forgiveness in the record of their deeds}}
\hadithdefcmd{ibnmajah}{3819}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الْحَكَمُ بْنُ مُصْعَبٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ لَزِمَ الاِسْتِغْفَارَ جَعَلَ اللَّهُ لَهُ مِنْ كُلِّ هَمٍّ فَرَجًا وَمِنْ كُلِّ ضِيقٍ مَخْرَجًا وَرَزَقَهُ مِنْ حَيْثُ لاَ يَحْتَسِبُ ‏"‏ ‏.‏\hadithno{3819}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin 'Abbas that :the Messenger of Allah said: "Whoever persists in asking for forgiveness, Allah will grant him relief from every worry, and a way out from every hardship, and will grant him provision from (sources) he could never imagine}}
\hadithdefcmd{ibnmajah}{3820}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَلَىِّ بْنِ زَيْدٍ، عَنْ أَبِي عُثْمَانَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ اجْعَلْنِي مِنَ الَّذِينَ إِذَا أَحْسَنُوا اسْتَبْشَرُوا وَإِذَا أَسَاءُوا اسْتَغْفَرُوا ‏"‏ ‏.‏\hadithno{3820}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that :the Prophet (saas) used to say: "Allahum-maj'alni minal-ladhina idha ahsanu istabsharu, wa idha asa'u istaghfaru (O Allah, make me one of those who, if they do good deeds, they rejoice, and if they do bad deeds, they seek forgiveness)}}
\hadithdefcmd{ibnmajah}{3821}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَقُولُ اللَّهُ تَبَارَكَ وَتَعَالَى مَنْ جَاءَ بِالْحَسَنَةِ فَلَهُ عَشْرُ أَمْثَالِهَا وَأَزِيدُ وَمَنْ جَاءَ بِالسَّيِّئَةِ فَجَزَاءُ سَيِّئَةٍ مِثْلُهَا أَوْ أَغْفِرُ وَمَنْ تَقَرَّبَ مِنِّي شِبْرًا تَقَرَّبْتُ مِنْهُ ذِرَاعًا وَمَنْ تَقَرَّبَ مِنِّي ذِرَاعًا تَقَرَّبْتُ مِنْهُ بَاعًا وَمَنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً وَمَنْ لَقِيَنِي بِقِرَابِ الأَرْضِ خَطِيئَةً ثُمَّ لاَ يُشْرِكُ بِي شَيْئًا لَقِيتُهُ بِمِثْلِهَا مَغْفِرَةً ‏"‏ ‏.‏\hadithno{3821}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr that :the Messenger of Allah (saas) said: "Allah, the Blessed and Exalted, said: 'Whoever does one good deed will have (the reward of) ten like it and more, and whoever does a bad deed will have one like it, or I will forgive him. Whoever draws near to Me a hand span, I draw near to him an arm's length; whoever comes to Me a forearm's length, I draw near him an arm's length; whoever comes to Me walking, I come to him in a hurry. Whoever meets Me with an earthful of sins, but does not associate anything in worship with Me, I will meet it (i.e., his sins) with forgiveness equal to that}}
\hadithdefcmd{ibnmajah}{3822}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَقُولُ اللَّهُ سُبْحَانَهُ أَنَا عِنْدَ ظَنِّ عَبْدِي بِي وَأَنَا مَعَهُ حِينَ يَذْكُرُنِي فَإِنْ ذَكَرَنِي فِي نَفْسِهِ ذَكَرْتُهُ فِي نَفْسِي وَإِنْ ذَكَرَنِي فِي مَلإٍ ذَكَرْتُهُ فِي مَلإٍ خَيْرٍ مِنْهُمْ وَإِنِ اقْتَرَبَ إِلَىَّ شِبْرًا اقْتَرَبْتُ إِلَيْهِ ذِرَاعًا وَإِنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏ ‏.‏\hadithno{3822}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (saas) said: "Allah says, 'I am as My slave thinks I am, and I am with him when he mentions Me. If he makes mention of Me to himself, I make mention of him to Myself; and if he makes mention of Me in an assembly, I make mention of him in an assembly better than it. And if he draws to Me a hand-span length, I draw near to him a forearm's length. And if he comes to Me walking, I go to him in a hurry}}
\hadithdefcmd{ibnmajah}{3823}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُّ عَمَلِ ابْنِ آدَمَ يُضَاعَفُ لَهُ الْحَسَنَةُ بِعَشْرِ أَمْثَالِهَا إِلَى سَبْعِمِائَةِ ضِعْفٍ ‏.‏ قَالَ اللَّهُ سُبْحَانَهُ إِلاَّ الصَّوْمَ فَإِنَّهُ لِي وَأَنَا أَجْزِي بِهِ ‏"‏ ‏.‏\hadithno{3823}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger :of Allah (saas) said: "Every deed of the son of Adam will be multiplied for him, between ten and seven hundred times for each merit. Allah said: 'Except for fasting, for it is for Me and I shall reward for it.'" (sahih)}}
\hadithdefcmd{ibnmajah}{3824}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا جَرِيرٌ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، قَالَ سَمِعَنِي النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَنَا أَقُولُ، لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ قَالَ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ أَلاَ أَدُلُّكَ عَلَى كَلِمَةٍ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْتُ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قُلْ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{3824}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:"The Prophet (saas) heard me saying: 'La hawla wa la quwwata illa billah (there is no power and no strength except with Allah).' He said: 'O 'Abdullah bin Qais! Shall I not tell you of a word which is one of the treasures of Paradise?' I said: 'Yes, O Messenger of Allah.' He said: 'Say: La hawla wa la quwwata illa billah (There is no power and no strength except with Allah)}}
\hadithdefcmd{ibnmajah}{3825}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَلاَ أَدُلُّكَ عَلَى كَنْزٍ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْتُ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{3825}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah (saas) said to me: "Shall I not tell you of a treasure which is one of the treasures of Paradise?' I said: 'Yes, O Messenger of Allah.' He said: 'La hawla wa la quwwata illa billah (There is no power and no strength except with Allah).'" (sahih)}}
\hadithdefcmd{ibnmajah}{3826}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدٍ الْمَدَنِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مَعْنٍ، حَدَّثَنَا خَالِدُ بْنُ سَعِيدٍ، عَنْ أَبِي زَيْنَبَ، مَوْلَى حَازِمِ بْنِ حَرْمَلَةَ عَنْ حَازِمِ بْنِ حَرْمَلَةَ، قَالَ مَرَرْتُ بِالنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ لِي ‏ "‏ يَا حَازِمُ أَكْثِرْ مِنْ قَوْلِ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ فَإِنَّهَا مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{3826}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hazim bin Harmalah said:"I passed by the Prophet (saas) and he said to me: 'O Hazim, say often: "La hawla wa la quwwata illa billah (there is no power and no strength except with Allah)," for it is one of the treasures of Paradise}}
